#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class StandardServiceBaseInfo(object):

    def __init__(self):
        self._biz_status = None
        self._category_id = None
        self._service_code = None
        self._service_name = None

    @property
    def biz_status(self):
        return self._biz_status

    @biz_status.setter
    def biz_status(self, value):
        self._biz_status = value
    @property
    def category_id(self):
        return self._category_id

    @category_id.setter
    def category_id(self, value):
        self._category_id = value
    @property
    def service_code(self):
        return self._service_code

    @service_code.setter
    def service_code(self, value):
        self._service_code = value
    @property
    def service_name(self):
        return self._service_name

    @service_name.setter
    def service_name(self, value):
        self._service_name = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_status:
            if hasattr(self.biz_status, 'to_alipay_dict'):
                params['biz_status'] = self.biz_status.to_alipay_dict()
            else:
                params['biz_status'] = self.biz_status
        if self.category_id:
            if hasattr(self.category_id, 'to_alipay_dict'):
                params['category_id'] = self.category_id.to_alipay_dict()
            else:
                params['category_id'] = self.category_id
        if self.service_code:
            if hasattr(self.service_code, 'to_alipay_dict'):
                params['service_code'] = self.service_code.to_alipay_dict()
            else:
                params['service_code'] = self.service_code
        if self.service_name:
            if hasattr(self.service_name, 'to_alipay_dict'):
                params['service_name'] = self.service_name.to_alipay_dict()
            else:
                params['service_name'] = self.service_name
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = StandardServiceBaseInfo()
        if 'biz_status' in d:
            o.biz_status = d['biz_status']
        if 'category_id' in d:
            o.category_id = d['category_id']
        if 'service_code' in d:
            o.service_code = d['service_code']
        if 'service_name' in d:
            o.service_name = d['service_name']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.CodeResInfo import CodeResInfo


class ZhimaCreditEpProductCodeApplyResponse(AlipayResponse):

    def __init__(self):
        super(ZhimaCreditEpProductCodeApplyResponse, self).__init__()
        self._apply_no = None
        self._code_list = None

    @property
    def apply_no(self):
        return self._apply_no

    @apply_no.setter
    def apply_no(self, value):
        self._apply_no = value
    @property
    def code_list(self):
        return self._code_list

    @code_list.setter
    def code_list(self, value):
        if isinstance(value, list):
            self._code_list = list()
            for i in value:
                if isinstance(i, CodeResInfo):
                    self._code_list.append(i)
                else:
                    self._code_list.append(CodeResInfo.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(ZhimaCreditEpProductCodeApplyResponse, self).parse_response_content(response_content)
        if 'apply_no' in response:
            self.apply_no = response['apply_no']
        if 'code_list' in response:
            self.code_list = response['code_list']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayMerchantOrderHahaNobizcontentCreateModel(object):

    def __init__(self):
        self._delete = None
        self._input = None

    @property
    def delete(self):
        return self._delete

    @delete.setter
    def delete(self, value):
        self._delete = value
    @property
    def input(self):
        return self._input

    @input.setter
    def input(self, value):
        self._input = value


    def to_alipay_dict(self):
        params = dict()
        if self.delete:
            if hasattr(self.delete, 'to_alipay_dict'):
                params['delete'] = self.delete.to_alipay_dict()
            else:
                params['delete'] = self.delete
        if self.input:
            if hasattr(self.input, 'to_alipay_dict'):
                params['input'] = self.input.to_alipay_dict()
            else:
                params['input'] = self.input
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayMerchantOrderHahaNobizcontentCreateModel()
        if 'delete' in d:
            o.delete = d['delete']
        if 'input' in d:
            o.input = d['input']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class PosCookDishQryDetailModel(object):

    def __init__(self):
        self._category_big_id = None
        self._dish_id = None
        self._dish_img = None
        self._dish_name = None
        self._dish_stall_ref = None
        self._min_price = None
        self._multi_spec = None
        self._special_tag = None
        self._spicy_tag = None
        self._status = None
        self._type = None
        self._unit_name = None

    @property
    def category_big_id(self):
        return self._category_big_id

    @category_big_id.setter
    def category_big_id(self, value):
        self._category_big_id = value
    @property
    def dish_id(self):
        return self._dish_id

    @dish_id.setter
    def dish_id(self, value):
        self._dish_id = value
    @property
    def dish_img(self):
        return self._dish_img

    @dish_img.setter
    def dish_img(self, value):
        self._dish_img = value
    @property
    def dish_name(self):
        return self._dish_name

    @dish_name.setter
    def dish_name(self, value):
        self._dish_name = value
    @property
    def dish_stall_ref(self):
        return self._dish_stall_ref

    @dish_stall_ref.setter
    def dish_stall_ref(self, value):
        self._dish_stall_ref = value
    @property
    def min_price(self):
        return self._min_price

    @min_price.setter
    def min_price(self, value):
        self._min_price = value
    @property
    def multi_spec(self):
        return self._multi_spec

    @multi_spec.setter
    def multi_spec(self, value):
        self._multi_spec = value
    @property
    def special_tag(self):
        return self._special_tag

    @special_tag.setter
    def special_tag(self, value):
        self._special_tag = value
    @property
    def spicy_tag(self):
        return self._spicy_tag

    @spicy_tag.setter
    def spicy_tag(self, value):
        self._spicy_tag = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def type(self):
        return self._type

    @type.setter
    def type(self, value):
        self._type = value
    @property
    def unit_name(self):
        return self._unit_name

    @unit_name.setter
    def unit_name(self, value):
        self._unit_name = value


    def to_alipay_dict(self):
        params = dict()
        if self.category_big_id:
            if hasattr(self.category_big_id, 'to_alipay_dict'):
                params['category_big_id'] = self.category_big_id.to_alipay_dict()
            else:
                params['category_big_id'] = self.category_big_id
        if self.dish_id:
            if hasattr(self.dish_id, 'to_alipay_dict'):
                params['dish_id'] = self.dish_id.to_alipay_dict()
            else:
                params['dish_id'] = self.dish_id
        if self.dish_img:
            if hasattr(self.dish_img, 'to_alipay_dict'):
                params['dish_img'] = self.dish_img.to_alipay_dict()
            else:
                params['dish_img'] = self.dish_img
        if self.dish_name:
            if hasattr(self.dish_name, 'to_alipay_dict'):
                params['dish_name'] = self.dish_name.to_alipay_dict()
            else:
                params['dish_name'] = self.dish_name
        if self.dish_stall_ref:
            if hasattr(self.dish_stall_ref, 'to_alipay_dict'):
                params['dish_stall_ref'] = self.dish_stall_ref.to_alipay_dict()
            else:
                params['dish_stall_ref'] = self.dish_stall_ref
        if self.min_price:
            if hasattr(self.min_price, 'to_alipay_dict'):
                params['min_price'] = self.min_price.to_alipay_dict()
            else:
                params['min_price'] = self.min_price
        if self.multi_spec:
            if hasattr(self.multi_spec, 'to_alipay_dict'):
                params['multi_spec'] = self.multi_spec.to_alipay_dict()
            else:
                params['multi_spec'] = self.multi_spec
        if self.special_tag:
            if hasattr(self.special_tag, 'to_alipay_dict'):
                params['special_tag'] = self.special_tag.to_alipay_dict()
            else:
                params['special_tag'] = self.special_tag
        if self.spicy_tag:
            if hasattr(self.spicy_tag, 'to_alipay_dict'):
                params['spicy_tag'] = self.spicy_tag.to_alipay_dict()
            else:
                params['spicy_tag'] = self.spicy_tag
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        if self.type:
            if hasattr(self.type, 'to_alipay_dict'):
                params['type'] = self.type.to_alipay_dict()
            else:
                params['type'] = self.type
        if self.unit_name:
            if hasattr(self.unit_name, 'to_alipay_dict'):
                params['unit_name'] = self.unit_name.to_alipay_dict()
            else:
                params['unit_name'] = self.unit_name
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = PosCookDishQryDetailModel()
        if 'category_big_id' in d:
            o.category_big_id = d['category_big_id']
        if 'dish_id' in d:
            o.dish_id = d['dish_id']
        if 'dish_img' in d:
            o.dish_img = d['dish_img']
        if 'dish_name' in d:
            o.dish_name = d['dish_name']
        if 'dish_stall_ref' in d:
            o.dish_stall_ref = d['dish_stall_ref']
        if 'min_price' in d:
            o.min_price = d['min_price']
        if 'multi_spec' in d:
            o.multi_spec = d['multi_spec']
        if 'special_tag' in d:
            o.special_tag = d['special_tag']
        if 'spicy_tag' in d:
            o.spicy_tag = d['spicy_tag']
        if 'status' in d:
            o.status = d['status']
        if 'type' in d:
            o.type = d['type']
        if 'unit_name' in d:
            o.unit_name = d['unit_name']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.PosOrderDeviceInfoVO import PosOrderDeviceInfoVO


class PosOrderInfoVO(object):

    def __init__(self):
        self._device_amount = None
        self._isv_name = None
        self._isv_pid = None
        self._machine_infos = None
        self._merchant_mobile = None
        self._merchant_name = None
        self._order_amt = None
        self._order_channel = None
        self._order_no = None
        self._seller_id = None
        self._seller_name = None
        self._taobao_login_id = None

    @property
    def device_amount(self):
        return self._device_amount

    @device_amount.setter
    def device_amount(self, value):
        self._device_amount = value
    @property
    def isv_name(self):
        return self._isv_name

    @isv_name.setter
    def isv_name(self, value):
        self._isv_name = value
    @property
    def isv_pid(self):
        return self._isv_pid

    @isv_pid.setter
    def isv_pid(self, value):
        self._isv_pid = value
    @property
    def machine_infos(self):
        return self._machine_infos

    @machine_infos.setter
    def machine_infos(self, value):
        if isinstance(value, list):
            self._machine_infos = list()
            for i in value:
                if isinstance(i, PosOrderDeviceInfoVO):
                    self._machine_infos.append(i)
                else:
                    self._machine_infos.append(PosOrderDeviceInfoVO.from_alipay_dict(i))
    @property
    def merchant_mobile(self):
        return self._merchant_mobile

    @merchant_mobile.setter
    def merchant_mobile(self, value):
        self._merchant_mobile = value
    @property
    def merchant_name(self):
        return self._merchant_name

    @merchant_name.setter
    def merchant_name(self, value):
        self._merchant_name = value
    @property
    def order_amt(self):
        return self._order_amt

    @order_amt.setter
    def order_amt(self, value):
        self._order_amt = value
    @property
    def order_channel(self):
        return self._order_channel

    @order_channel.setter
    def order_channel(self, value):
        self._order_channel = value
    @property
    def order_no(self):
        return self._order_no

    @order_no.setter
    def order_no(self, value):
        self._order_no = value
    @property
    def seller_id(self):
        return self._seller_id

    @seller_id.setter
    def seller_id(self, value):
        self._seller_id = value
    @property
    def seller_name(self):
        return self._seller_name

    @seller_name.setter
    def seller_name(self, value):
        self._seller_name = value
    @property
    def taobao_login_id(self):
        return self._taobao_login_id

    @taobao_login_id.setter
    def taobao_login_id(self, value):
        self._taobao_login_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.device_amount:
            if hasattr(self.device_amount, 'to_alipay_dict'):
                params['device_amount'] = self.device_amount.to_alipay_dict()
            else:
                params['device_amount'] = self.device_amount
        if self.isv_name:
            if hasattr(self.isv_name, 'to_alipay_dict'):
                params['isv_name'] = self.isv_name.to_alipay_dict()
            else:
                params['isv_name'] = self.isv_name
        if self.isv_pid:
            if hasattr(self.isv_pid, 'to_alipay_dict'):
                params['isv_pid'] = self.isv_pid.to_alipay_dict()
            else:
                params['isv_pid'] = self.isv_pid
        if self.machine_infos:
            if isinstance(self.machine_infos, list):
                for i in range(0, len(self.machine_infos)):
                    element = self.machine_infos[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.machine_infos[i] = element.to_alipay_dict()
            if hasattr(self.machine_infos, 'to_alipay_dict'):
                params['machine_infos'] = self.machine_infos.to_alipay_dict()
            else:
                params['machine_infos'] = self.machine_infos
        if self.merchant_mobile:
            if hasattr(self.merchant_mobile, 'to_alipay_dict'):
                params['merchant_mobile'] = self.merchant_mobile.to_alipay_dict()
            else:
                params['merchant_mobile'] = self.merchant_mobile
        if self.merchant_name:
            if hasattr(self.merchant_name, 'to_alipay_dict'):
                params['merchant_name'] = self.merchant_name.to_alipay_dict()
            else:
                params['merchant_name'] = self.merchant_name
        if self.order_amt:
            if hasattr(self.order_amt, 'to_alipay_dict'):
                params['order_amt'] = self.order_amt.to_alipay_dict()
            else:
                params['order_amt'] = self.order_amt
        if self.order_channel:
            if hasattr(self.order_channel, 'to_alipay_dict'):
                params['order_channel'] = self.order_channel.to_alipay_dict()
            else:
                params['order_channel'] = self.order_channel
        if self.order_no:
            if hasattr(self.order_no, 'to_alipay_dict'):
                params['order_no'] = self.order_no.to_alipay_dict()
            else:
                params['order_no'] = self.order_no
        if self.seller_id:
            if hasattr(self.seller_id, 'to_alipay_dict'):
                params['seller_id'] = self.seller_id.to_alipay_dict()
            else:
                params['seller_id'] = self.seller_id
        if self.seller_name:
            if hasattr(self.seller_name, 'to_alipay_dict'):
                params['seller_name'] = self.seller_name.to_alipay_dict()
            else:
                params['seller_name'] = self.seller_name
        if self.taobao_login_id:
            if hasattr(self.taobao_login_id, 'to_alipay_dict'):
                params['taobao_login_id'] = self.taobao_login_id.to_alipay_dict()
            else:
                params['taobao_login_id'] = self.taobao_login_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = PosOrderInfoVO()
        if 'device_amount' in d:
            o.device_amount = d['device_amount']
        if 'isv_name' in d:
            o.isv_name = d['isv_name']
        if 'isv_pid' in d:
            o.isv_pid = d['isv_pid']
        if 'machine_infos' in d:
            o.machine_infos = d['machine_infos']
        if 'merchant_mobile' in d:
            o.merchant_mobile = d['merchant_mobile']
        if 'merchant_name' in d:
            o.merchant_name = d['merchant_name']
        if 'order_amt' in d:
            o.order_amt = d['order_amt']
        if 'order_channel' in d:
            o.order_channel = d['order_channel']
        if 'order_no' in d:
            o.order_no = d['order_no']
        if 'seller_id' in d:
            o.seller_id = d['seller_id']
        if 'seller_name' in d:
            o.seller_name = d['seller_name']
        if 'taobao_login_id' in d:
            o.taobao_login_id = d['taobao_login_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.KbdishCookInfo import KbdishCookInfo


class KoubeiCateringDishCookSyncModel(object):

    def __init__(self):
        self._biz_type = None
        self._kb_dish_cook = None
        self._syn_type = None

    @property
    def biz_type(self):
        return self._biz_type

    @biz_type.setter
    def biz_type(self, value):
        self._biz_type = value
    @property
    def kb_dish_cook(self):
        return self._kb_dish_cook

    @kb_dish_cook.setter
    def kb_dish_cook(self, value):
        if isinstance(value, KbdishCookInfo):
            self._kb_dish_cook = value
        else:
            self._kb_dish_cook = KbdishCookInfo.from_alipay_dict(value)
    @property
    def syn_type(self):
        return self._syn_type

    @syn_type.setter
    def syn_type(self, value):
        self._syn_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_type:
            if hasattr(self.biz_type, 'to_alipay_dict'):
                params['biz_type'] = self.biz_type.to_alipay_dict()
            else:
                params['biz_type'] = self.biz_type
        if self.kb_dish_cook:
            if hasattr(self.kb_dish_cook, 'to_alipay_dict'):
                params['kb_dish_cook'] = self.kb_dish_cook.to_alipay_dict()
            else:
                params['kb_dish_cook'] = self.kb_dish_cook
        if self.syn_type:
            if hasattr(self.syn_type, 'to_alipay_dict'):
                params['syn_type'] = self.syn_type.to_alipay_dict()
            else:
                params['syn_type'] = self.syn_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiCateringDishCookSyncModel()
        if 'biz_type' in d:
            o.biz_type = d['biz_type']
        if 'kb_dish_cook' in d:
            o.kb_dish_cook = d['kb_dish_cook']
        if 'syn_type' in d:
            o.syn_type = d['syn_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayTradeAdvanceConsultModel(object):

    def __init__(self):
        self._agreement_no = None
        self._alipay_user_id = None
        self._consult_scene = None
        self._estimated_order_amount = None
        self._industry_product_code = None
        self._need_user_risk_prediction = None
        self._out_trade_no = None
        self._sub_merchant_id = None
        self._sub_merchant_type = None
        self._trade_digest = None
        self._user_out_binding_phone = None

    @property
    def agreement_no(self):
        return self._agreement_no

    @agreement_no.setter
    def agreement_no(self, value):
        self._agreement_no = value
    @property
    def alipay_user_id(self):
        return self._alipay_user_id

    @alipay_user_id.setter
    def alipay_user_id(self, value):
        self._alipay_user_id = value
    @property
    def consult_scene(self):
        return self._consult_scene

    @consult_scene.setter
    def consult_scene(self, value):
        self._consult_scene = value
    @property
    def estimated_order_amount(self):
        return self._estimated_order_amount

    @estimated_order_amount.setter
    def estimated_order_amount(self, value):
        self._estimated_order_amount = value
    @property
    def industry_product_code(self):
        return self._industry_product_code

    @industry_product_code.setter
    def industry_product_code(self, value):
        self._industry_product_code = value
    @property
    def need_user_risk_prediction(self):
        return self._need_user_risk_prediction

    @need_user_risk_prediction.setter
    def need_user_risk_prediction(self, value):
        self._need_user_risk_prediction = value
    @property
    def out_trade_no(self):
        return self._out_trade_no

    @out_trade_no.setter
    def out_trade_no(self, value):
        self._out_trade_no = value
    @property
    def sub_merchant_id(self):
        return self._sub_merchant_id

    @sub_merchant_id.setter
    def sub_merchant_id(self, value):
        self._sub_merchant_id = value
    @property
    def sub_merchant_type(self):
        return self._sub_merchant_type

    @sub_merchant_type.setter
    def sub_merchant_type(self, value):
        self._sub_merchant_type = value
    @property
    def trade_digest(self):
        return self._trade_digest

    @trade_digest.setter
    def trade_digest(self, value):
        self._trade_digest = value
    @property
    def user_out_binding_phone(self):
        return self._user_out_binding_phone

    @user_out_binding_phone.setter
    def user_out_binding_phone(self, value):
        self._user_out_binding_phone = value


    def to_alipay_dict(self):
        params = dict()
        if self.agreement_no:
            if hasattr(self.agreement_no, 'to_alipay_dict'):
                params['agreement_no'] = self.agreement_no.to_alipay_dict()
            else:
                params['agreement_no'] = self.agreement_no
        if self.alipay_user_id:
            if hasattr(self.alipay_user_id, 'to_alipay_dict'):
                params['alipay_user_id'] = self.alipay_user_id.to_alipay_dict()
            else:
                params['alipay_user_id'] = self.alipay_user_id
        if self.consult_scene:
            if hasattr(self.consult_scene, 'to_alipay_dict'):
                params['consult_scene'] = self.consult_scene.to_alipay_dict()
            else:
                params['consult_scene'] = self.consult_scene
        if self.estimated_order_amount:
            if hasattr(self.estimated_order_amount, 'to_alipay_dict'):
                params['estimated_order_amount'] = self.estimated_order_amount.to_alipay_dict()
            else:
                params['estimated_order_amount'] = self.estimated_order_amount
        if self.industry_product_code:
            if hasattr(self.industry_product_code, 'to_alipay_dict'):
                params['industry_product_code'] = self.industry_product_code.to_alipay_dict()
            else:
                params['industry_product_code'] = self.industry_product_code
        if self.need_user_risk_prediction:
            if hasattr(self.need_user_risk_prediction, 'to_alipay_dict'):
                params['need_user_risk_prediction'] = self.need_user_risk_prediction.to_alipay_dict()
            else:
                params['need_user_risk_prediction'] = self.need_user_risk_prediction
        if self.out_trade_no:
            if hasattr(self.out_trade_no, 'to_alipay_dict'):
                params['out_trade_no'] = self.out_trade_no.to_alipay_dict()
            else:
                params['out_trade_no'] = self.out_trade_no
        if self.sub_merchant_id:
            if hasattr(self.sub_merchant_id, 'to_alipay_dict'):
                params['sub_merchant_id'] = self.sub_merchant_id.to_alipay_dict()
            else:
                params['sub_merchant_id'] = self.sub_merchant_id
        if self.sub_merchant_type:
            if hasattr(self.sub_merchant_type, 'to_alipay_dict'):
                params['sub_merchant_type'] = self.sub_merchant_type.to_alipay_dict()
            else:
                params['sub_merchant_type'] = self.sub_merchant_type
        if self.trade_digest:
            if hasattr(self.trade_digest, 'to_alipay_dict'):
                params['trade_digest'] = self.trade_digest.to_alipay_dict()
            else:
                params['trade_digest'] = self.trade_digest
        if self.user_out_binding_phone:
            if hasattr(self.user_out_binding_phone, 'to_alipay_dict'):
                params['user_out_binding_phone'] = self.user_out_binding_phone.to_alipay_dict()
            else:
                params['user_out_binding_phone'] = self.user_out_binding_phone
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayTradeAdvanceConsultModel()
        if 'agreement_no' in d:
            o.agreement_no = d['agreement_no']
        if 'alipay_user_id' in d:
            o.alipay_user_id = d['alipay_user_id']
        if 'consult_scene' in d:
            o.consult_scene = d['consult_scene']
        if 'estimated_order_amount' in d:
            o.estimated_order_amount = d['estimated_order_amount']
        if 'industry_product_code' in d:
            o.industry_product_code = d['industry_product_code']
        if 'need_user_risk_prediction' in d:
            o.need_user_risk_prediction = d['need_user_risk_prediction']
        if 'out_trade_no' in d:
            o.out_trade_no = d['out_trade_no']
        if 'sub_merchant_id' in d:
            o.sub_merchant_id = d['sub_merchant_id']
        if 'sub_merchant_type' in d:
            o.sub_merchant_type = d['sub_merchant_type']
        if 'trade_digest' in d:
            o.trade_digest = d['trade_digest']
        if 'user_out_binding_phone' in d:
            o.user_out_binding_phone = d['user_out_binding_phone']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.InsAgreementDTO import InsAgreementDTO
from alipay.aop.api.domain.PurchaseInsurePlanDTO import PurchaseInsurePlanDTO
from alipay.aop.api.domain.InsPeriodDTO import InsPeriodDTO


class PurchaseQueryResultDTO(object):

    def __init__(self):
        self._agreement_list = None
        self._effect_time = None
        self._end_time = None
        self._inst_id = None
        self._inst_name = None
        self._insure_plans = None
        self._issued_amount = None
        self._partner_org_id = None
        self._product_code = None
        self._product_desc = None
        self._product_info_url = None
        self._product_name = None
        self._product_plan_id = None
        self._purchase_contract_id = None
        self._related_subject_id = None
        self._related_subject_type = None
        self._renew = None
        self._renew_period = None
        self._show_uninsured_option = None
        self._status = None
        self._total_amount = None
        self._user_id = None

    @property
    def agreement_list(self):
        return self._agreement_list

    @agreement_list.setter
    def agreement_list(self, value):
        if isinstance(value, list):
            self._agreement_list = list()
            for i in value:
                if isinstance(i, InsAgreementDTO):
                    self._agreement_list.append(i)
                else:
                    self._agreement_list.append(InsAgreementDTO.from_alipay_dict(i))
    @property
    def effect_time(self):
        return self._effect_time

    @effect_time.setter
    def effect_time(self, value):
        self._effect_time = value
    @property
    def end_time(self):
        return self._end_time

    @end_time.setter
    def end_time(self, value):
        self._end_time = value
    @property
    def inst_id(self):
        return self._inst_id

    @inst_id.setter
    def inst_id(self, value):
        self._inst_id = value
    @property
    def inst_name(self):
        return self._inst_name

    @inst_name.setter
    def inst_name(self, value):
        self._inst_name = value
    @property
    def insure_plans(self):
        return self._insure_plans

    @insure_plans.setter
    def insure_plans(self, value):
        if isinstance(value, list):
            self._insure_plans = list()
            for i in value:
                if isinstance(i, PurchaseInsurePlanDTO):
                    self._insure_plans.append(i)
                else:
                    self._insure_plans.append(PurchaseInsurePlanDTO.from_alipay_dict(i))
    @property
    def issued_amount(self):
        return self._issued_amount

    @issued_amount.setter
    def issued_amount(self, value):
        self._issued_amount = value
    @property
    def partner_org_id(self):
        return self._partner_org_id

    @partner_org_id.setter
    def partner_org_id(self, value):
        self._partner_org_id = value
    @property
    def product_code(self):
        return self._product_code

    @product_code.setter
    def product_code(self, value):
        self._product_code = value
    @property
    def product_desc(self):
        return self._product_desc

    @product_desc.setter
    def product_desc(self, value):
        self._product_desc = value
    @property
    def product_info_url(self):
        return self._product_info_url

    @product_info_url.setter
    def product_info_url(self, value):
        self._product_info_url = value
    @property
    def product_name(self):
        return self._product_name

    @product_name.setter
    def product_name(self, value):
        self._product_name = value
    @property
    def product_plan_id(self):
        return self._product_plan_id

    @product_plan_id.setter
    def product_plan_id(self, value):
        self._product_plan_id = value
    @property
    def purchase_contract_id(self):
        return self._purchase_contract_id

    @purchase_contract_id.setter
    def purchase_contract_id(self, value):
        self._purchase_contract_id = value
    @property
    def related_subject_id(self):
        return self._related_subject_id

    @related_subject_id.setter
    def related_subject_id(self, value):
        self._related_subject_id = value
    @property
    def related_subject_type(self):
        return self._related_subject_type

    @related_subject_type.setter
    def related_subject_type(self, value):
        self._related_subject_type = value
    @property
    def renew(self):
        return self._renew

    @renew.setter
    def renew(self, value):
        self._renew = value
    @property
    def renew_period(self):
        return self._renew_period

    @renew_period.setter
    def renew_period(self, value):
        if isinstance(value, InsPeriodDTO):
            self._renew_period = value
        else:
            self._renew_period = InsPeriodDTO.from_alipay_dict(value)
    @property
    def show_uninsured_option(self):
        return self._show_uninsured_option

    @show_uninsured_option.setter
    def show_uninsured_option(self, value):
        self._show_uninsured_option = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def total_amount(self):
        return self._total_amount

    @total_amount.setter
    def total_amount(self, value):
        self._total_amount = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.agreement_list:
            if isinstance(self.agreement_list, list):
                for i in range(0, len(self.agreement_list)):
                    element = self.agreement_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.agreement_list[i] = element.to_alipay_dict()
            if hasattr(self.agreement_list, 'to_alipay_dict'):
                params['agreement_list'] = self.agreement_list.to_alipay_dict()
            else:
                params['agreement_list'] = self.agreement_list
        if self.effect_time:
            if hasattr(self.effect_time, 'to_alipay_dict'):
                params['effect_time'] = self.effect_time.to_alipay_dict()
            else:
                params['effect_time'] = self.effect_time
        if self.end_time:
            if hasattr(self.end_time, 'to_alipay_dict'):
                params['end_time'] = self.end_time.to_alipay_dict()
            else:
                params['end_time'] = self.end_time
        if self.inst_id:
            if hasattr(self.inst_id, 'to_alipay_dict'):
                params['inst_id'] = self.inst_id.to_alipay_dict()
            else:
                params['inst_id'] = self.inst_id
        if self.inst_name:
            if hasattr(self.inst_name, 'to_alipay_dict'):
                params['inst_name'] = self.inst_name.to_alipay_dict()
            else:
                params['inst_name'] = self.inst_name
        if self.insure_plans:
            if isinstance(self.insure_plans, list):
                for i in range(0, len(self.insure_plans)):
                    element = self.insure_plans[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.insure_plans[i] = element.to_alipay_dict()
            if hasattr(self.insure_plans, 'to_alipay_dict'):
                params['insure_plans'] = self.insure_plans.to_alipay_dict()
            else:
                params['insure_plans'] = self.insure_plans
        if self.issued_amount:
            if hasattr(self.issued_amount, 'to_alipay_dict'):
                params['issued_amount'] = self.issued_amount.to_alipay_dict()
            else:
                params['issued_amount'] = self.issued_amount
        if self.partner_org_id:
            if hasattr(self.partner_org_id, 'to_alipay_dict'):
                params['partner_org_id'] = self.partner_org_id.to_alipay_dict()
            else:
                params['partner_org_id'] = self.partner_org_id
        if self.product_code:
            if hasattr(self.product_code, 'to_alipay_dict'):
                params['product_code'] = self.product_code.to_alipay_dict()
            else:
                params['product_code'] = self.product_code
        if self.product_desc:
            if hasattr(self.product_desc, 'to_alipay_dict'):
                params['product_desc'] = self.product_desc.to_alipay_dict()
            else:
                params['product_desc'] = self.product_desc
        if self.product_info_url:
            if hasattr(self.product_info_url, 'to_alipay_dict'):
                params['product_info_url'] = self.product_info_url.to_alipay_dict()
            else:
                params['product_info_url'] = self.product_info_url
        if self.product_name:
            if hasattr(self.product_name, 'to_alipay_dict'):
                params['product_name'] = self.product_name.to_alipay_dict()
            else:
                params['product_name'] = self.product_name
        if self.product_plan_id:
            if hasattr(self.product_plan_id, 'to_alipay_dict'):
                params['product_plan_id'] = self.product_plan_id.to_alipay_dict()
            else:
                params['product_plan_id'] = self.product_plan_id
        if self.purchase_contract_id:
            if hasattr(self.purchase_contract_id, 'to_alipay_dict'):
                params['purchase_contract_id'] = self.purchase_contract_id.to_alipay_dict()
            else:
                params['purchase_contract_id'] = self.purchase_contract_id
        if self.related_subject_id:
            if hasattr(self.related_subject_id, 'to_alipay_dict'):
                params['related_subject_id'] = self.related_subject_id.to_alipay_dict()
            else:
                params['related_subject_id'] = self.related_subject_id
        if self.related_subject_type:
            if hasattr(self.related_subject_type, 'to_alipay_dict'):
                params['related_subject_type'] = self.related_subject_type.to_alipay_dict()
            else:
                params['related_subject_type'] = self.related_subject_type
        if self.renew:
            if hasattr(self.renew, 'to_alipay_dict'):
                params['renew'] = self.renew.to_alipay_dict()
            else:
                params['renew'] = self.renew
        if self.renew_period:
            if hasattr(self.renew_period, 'to_alipay_dict'):
                params['renew_period'] = self.renew_period.to_alipay_dict()
            else:
                params['renew_period'] = self.renew_period
        if self.show_uninsured_option:
            if hasattr(self.show_uninsured_option, 'to_alipay_dict'):
                params['show_uninsured_option'] = self.show_uninsured_option.to_alipay_dict()
            else:
                params['show_uninsured_option'] = self.show_uninsured_option
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        if self.total_amount:
            if hasattr(self.total_amount, 'to_alipay_dict'):
                params['total_amount'] = self.total_amount.to_alipay_dict()
            else:
                params['total_amount'] = self.total_amount
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = PurchaseQueryResultDTO()
        if 'agreement_list' in d:
            o.agreement_list = d['agreement_list']
        if 'effect_time' in d:
            o.effect_time = d['effect_time']
        if 'end_time' in d:
            o.end_time = d['end_time']
        if 'inst_id' in d:
            o.inst_id = d['inst_id']
        if 'inst_name' in d:
            o.inst_name = d['inst_name']
        if 'insure_plans' in d:
            o.insure_plans = d['insure_plans']
        if 'issued_amount' in d:
            o.issued_amount = d['issued_amount']
        if 'partner_org_id' in d:
            o.partner_org_id = d['partner_org_id']
        if 'product_code' in d:
            o.product_code = d['product_code']
        if 'product_desc' in d:
            o.product_desc = d['product_desc']
        if 'product_info_url' in d:
            o.product_info_url = d['product_info_url']
        if 'product_name' in d:
            o.product_name = d['product_name']
        if 'product_plan_id' in d:
            o.product_plan_id = d['product_plan_id']
        if 'purchase_contract_id' in d:
            o.purchase_contract_id = d['purchase_contract_id']
        if 'related_subject_id' in d:
            o.related_subject_id = d['related_subject_id']
        if 'related_subject_type' in d:
            o.related_subject_type = d['related_subject_type']
        if 'renew' in d:
            o.renew = d['renew']
        if 'renew_period' in d:
            o.renew_period = d['renew_period']
        if 'show_uninsured_option' in d:
            o.show_uninsured_option = d['show_uninsured_option']
        if 'status' in d:
            o.status = d['status']
        if 'total_amount' in d:
            o.total_amount = d['total_amount']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceDataScenicSyncModel(object):

    def __init__(self):
        self._code_value = None
        self._isv_name = None
        self._isv_scenic_address = None
        self._isv_scenic_name = None
        self._outer_id = None
        self._scenic_app_id = None
        self._scenic_id = None

    @property
    def code_value(self):
        return self._code_value

    @code_value.setter
    def code_value(self, value):
        if isinstance(value, list):
            self._code_value = list()
            for i in value:
                self._code_value.append(i)
    @property
    def isv_name(self):
        return self._isv_name

    @isv_name.setter
    def isv_name(self, value):
        self._isv_name = value
    @property
    def isv_scenic_address(self):
        return self._isv_scenic_address

    @isv_scenic_address.setter
    def isv_scenic_address(self, value):
        self._isv_scenic_address = value
    @property
    def isv_scenic_name(self):
        return self._isv_scenic_name

    @isv_scenic_name.setter
    def isv_scenic_name(self, value):
        self._isv_scenic_name = value
    @property
    def outer_id(self):
        return self._outer_id

    @outer_id.setter
    def outer_id(self, value):
        self._outer_id = value
    @property
    def scenic_app_id(self):
        return self._scenic_app_id

    @scenic_app_id.setter
    def scenic_app_id(self, value):
        self._scenic_app_id = value
    @property
    def scenic_id(self):
        return self._scenic_id

    @scenic_id.setter
    def scenic_id(self, value):
        self._scenic_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.code_value:
            if isinstance(self.code_value, list):
                for i in range(0, len(self.code_value)):
                    element = self.code_value[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.code_value[i] = element.to_alipay_dict()
            if hasattr(self.code_value, 'to_alipay_dict'):
                params['code_value'] = self.code_value.to_alipay_dict()
            else:
                params['code_value'] = self.code_value
        if self.isv_name:
            if hasattr(self.isv_name, 'to_alipay_dict'):
                params['isv_name'] = self.isv_name.to_alipay_dict()
            else:
                params['isv_name'] = self.isv_name
        if self.isv_scenic_address:
            if hasattr(self.isv_scenic_address, 'to_alipay_dict'):
                params['isv_scenic_address'] = self.isv_scenic_address.to_alipay_dict()
            else:
                params['isv_scenic_address'] = self.isv_scenic_address
        if self.isv_scenic_name:
            if hasattr(self.isv_scenic_name, 'to_alipay_dict'):
                params['isv_scenic_name'] = self.isv_scenic_name.to_alipay_dict()
            else:
                params['isv_scenic_name'] = self.isv_scenic_name
        if self.outer_id:
            if hasattr(self.outer_id, 'to_alipay_dict'):
                params['outer_id'] = self.outer_id.to_alipay_dict()
            else:
                params['outer_id'] = self.outer_id
        if self.scenic_app_id:
            if hasattr(self.scenic_app_id, 'to_alipay_dict'):
                params['scenic_app_id'] = self.scenic_app_id.to_alipay_dict()
            else:
                params['scenic_app_id'] = self.scenic_app_id
        if self.scenic_id:
            if hasattr(self.scenic_id, 'to_alipay_dict'):
                params['scenic_id'] = self.scenic_id.to_alipay_dict()
            else:
                params['scenic_id'] = self.scenic_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceDataScenicSyncModel()
        if 'code_value' in d:
            o.code_value = d['code_value']
        if 'isv_name' in d:
            o.isv_name = d['isv_name']
        if 'isv_scenic_address' in d:
            o.isv_scenic_address = d['isv_scenic_address']
        if 'isv_scenic_name' in d:
            o.isv_scenic_name = d['isv_scenic_name']
        if 'outer_id' in d:
            o.outer_id = d['outer_id']
        if 'scenic_app_id' in d:
            o.scenic_app_id = d['scenic_app_id']
        if 'scenic_id' in d:
            o.scenic_id = d['scenic_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.FileItem import FileItem
from alipay.aop.api.constant.ParamConstants import *




class AlipaySecurityRiskDetectRequest(object):

    def __init__(self, biz_model=None):
        self._biz_model = biz_model
        self._buyer_account_no = None
        self._buyer_bind_bankcard = None
        self._buyer_bind_bankcard_type = None
        self._buyer_bind_mobile = None
        self._buyer_grade = None
        self._buyer_identity_no = None
        self._buyer_identity_type = None
        self._buyer_real_name = None
        self._buyer_reg_date = None
        self._buyer_reg_email = None
        self._buyer_reg_mobile = None
        self._buyer_scene_bankcard = None
        self._buyer_scene_bankcard_type = None
        self._buyer_scene_email = None
        self._buyer_scene_mobile = None
        self._currency = None
        self._env_client_base_band = None
        self._env_client_base_station = None
        self._env_client_coordinates = None
        self._env_client_imei = None
        self._env_client_imsi = None
        self._env_client_ios_udid = None
        self._env_client_ip = None
        self._env_client_mac = None
        self._env_client_screen = None
        self._env_client_uuid = None
        self._item_quantity = None
        self._item_unit_price = None
        self._js_token_id = None
        self._order_amount = None
        self._order_category = None
        self._order_credate_time = None
        self._order_item_city = None
        self._order_item_name = None
        self._order_no = None
        self._partner_id = None
        self._receiver_address = None
        self._receiver_city = None
        self._receiver_district = None
        self._receiver_email = None
        self._receiver_mobile = None
        self._receiver_name = None
        self._receiver_state = None
        self._receiver_zip = None
        self._scene_code = None
        self._seller_account_no = None
        self._seller_bind_bankcard = None
        self._seller_bind_bankcard_type = None
        self._seller_bind_mobile = None
        self._seller_identity_no = None
        self._seller_identity_type = None
        self._seller_real_name = None
        self._seller_reg_date = None
        self._seller_reg_email = None
        self._seller_reg_moile = None
        self._transport_type = None
        self._version = "1.0"
        self._terminal_type = None
        self._terminal_info = None
        self._prod_code = None
        self._notify_url = None
        self._return_url = None
        self._udf_params = None
        self._need_encrypt = False

    @property
    def biz_model(self):
        return self._biz_model

    @biz_model.setter
    def biz_model(self, value):
        self._biz_model = value

    @property
    def buyer_account_no(self):
        return self._buyer_account_no

    @buyer_account_no.setter
    def buyer_account_no(self, value):
        self._buyer_account_no = value
    @property
    def buyer_bind_bankcard(self):
        return self._buyer_bind_bankcard

    @buyer_bind_bankcard.setter
    def buyer_bind_bankcard(self, value):
        self._buyer_bind_bankcard = value
    @property
    def buyer_bind_bankcard_type(self):
        return self._buyer_bind_bankcard_type

    @buyer_bind_bankcard_type.setter
    def buyer_bind_bankcard_type(self, value):
        self._buyer_bind_bankcard_type = value
    @property
    def buyer_bind_mobile(self):
        return self._buyer_bind_mobile

    @buyer_bind_mobile.setter
    def buyer_bind_mobile(self, value):
        self._buyer_bind_mobile = value
    @property
    def buyer_grade(self):
        return self._buyer_grade

    @buyer_grade.setter
    def buyer_grade(self, value):
        self._buyer_grade = value
    @property
    def buyer_identity_no(self):
        return self._buyer_identity_no

    @buyer_identity_no.setter
    def buyer_identity_no(self, value):
        self._buyer_identity_no = value
    @property
    def buyer_identity_type(self):
        return self._buyer_identity_type

    @buyer_identity_type.setter
    def buyer_identity_type(self, value):
        self._buyer_identity_type = value
    @property
    def buyer_real_name(self):
        return self._buyer_real_name

    @buyer_real_name.setter
    def buyer_real_name(self, value):
        self._buyer_real_name = value
    @property
    def buyer_reg_date(self):
        return self._buyer_reg_date

    @buyer_reg_date.setter
    def buyer_reg_date(self, value):
        self._buyer_reg_date = value
    @property
    def buyer_reg_email(self):
        return self._buyer_reg_email

    @buyer_reg_email.setter
    def buyer_reg_email(self, value):
        self._buyer_reg_email = value
    @property
    def buyer_reg_mobile(self):
        return self._buyer_reg_mobile

    @buyer_reg_mobile.setter
    def buyer_reg_mobile(self, value):
        self._buyer_reg_mobile = value
    @property
    def buyer_scene_bankcard(self):
        return self._buyer_scene_bankcard

    @buyer_scene_bankcard.setter
    def buyer_scene_bankcard(self, value):
        self._buyer_scene_bankcard = value
    @property
    def buyer_scene_bankcard_type(self):
        return self._buyer_scene_bankcard_type

    @buyer_scene_bankcard_type.setter
    def buyer_scene_bankcard_type(self, value):
        self._buyer_scene_bankcard_type = value
    @property
    def buyer_scene_email(self):
        return self._buyer_scene_email

    @buyer_scene_email.setter
    def buyer_scene_email(self, value):
        self._buyer_scene_email = value
    @property
    def buyer_scene_mobile(self):
        return self._buyer_scene_mobile

    @buyer_scene_mobile.setter
    def buyer_scene_mobile(self, value):
        self._buyer_scene_mobile = value
    @property
    def currency(self):
        return self._currency

    @currency.setter
    def currency(self, value):
        self._currency = value
    @property
    def env_client_base_band(self):
        return self._env_client_base_band

    @env_client_base_band.setter
    def env_client_base_band(self, value):
        self._env_client_base_band = value
    @property
    def env_client_base_station(self):
        return self._env_client_base_station

    @env_client_base_station.setter
    def env_client_base_station(self, value):
        self._env_client_base_station = value
    @property
    def env_client_coordinates(self):
        return self._env_client_coordinates

    @env_client_coordinates.setter
    def env_client_coordinates(self, value):
        self._env_client_coordinates = value
    @property
    def env_client_imei(self):
        return self._env_client_imei

    @env_client_imei.setter
    def env_client_imei(self, value):
        self._env_client_imei = value
    @property
    def env_client_imsi(self):
        return self._env_client_imsi

    @env_client_imsi.setter
    def env_client_imsi(self, value):
        self._env_client_imsi = value
    @property
    def env_client_ios_udid(self):
        return self._env_client_ios_udid

    @env_client_ios_udid.setter
    def env_client_ios_udid(self, value):
        self._env_client_ios_udid = value
    @property
    def env_client_ip(self):
        return self._env_client_ip

    @env_client_ip.setter
    def env_client_ip(self, value):
        self._env_client_ip = value
    @property
    def env_client_mac(self):
        return self._env_client_mac

    @env_client_mac.setter
    def env_client_mac(self, value):
        self._env_client_mac = value
    @property
    def env_client_screen(self):
        return self._env_client_screen

    @env_client_screen.setter
    def env_client_screen(self, value):
        self._env_client_screen = value
    @property
    def env_client_uuid(self):
        return self._env_client_uuid

    @env_client_uuid.setter
    def env_client_uuid(self, value):
        self._env_client_uuid = value
    @property
    def item_quantity(self):
        return self._item_quantity

    @item_quantity.setter
    def item_quantity(self, value):
        self._item_quantity = value
    @property
    def item_unit_price(self):
        return self._item_unit_price

    @item_unit_price.setter
    def item_unit_price(self, value):
        self._item_unit_price = value
    @property
    def js_token_id(self):
        return self._js_token_id

    @js_token_id.setter
    def js_token_id(self, value):
        self._js_token_id = value
    @property
    def order_amount(self):
        return self._order_amount

    @order_amount.setter
    def order_amount(self, value):
        self._order_amount = value
    @property
    def order_category(self):
        return self._order_category

    @order_category.setter
    def order_category(self, value):
        self._order_category = value
    @property
    def order_credate_time(self):
        return self._order_credate_time

    @order_credate_time.setter
    def order_credate_time(self, value):
        self._order_credate_time = value
    @property
    def order_item_city(self):
        return self._order_item_city

    @order_item_city.setter
    def order_item_city(self, value):
        self._order_item_city = value
    @property
    def order_item_name(self):
        return self._order_item_name

    @order_item_name.setter
    def order_item_name(self, value):
        self._order_item_name = value
    @property
    def order_no(self):
        return self._order_no

    @order_no.setter
    def order_no(self, value):
        self._order_no = value
    @property
    def partner_id(self):
        return self._partner_id

    @partner_id.setter
    def partner_id(self, value):
        self._partner_id = value
    @property
    def receiver_address(self):
        return self._receiver_address

    @receiver_address.setter
    def receiver_address(self, value):
        self._receiver_address = value
    @property
    def receiver_city(self):
        return self._receiver_city

    @receiver_city.setter
    def receiver_city(self, value):
        self._receiver_city = value
    @property
    def receiver_district(self):
        return self._receiver_district

    @receiver_district.setter
    def receiver_district(self, value):
        self._receiver_district = value
    @property
    def receiver_email(self):
        return self._receiver_email

    @receiver_email.setter
    def receiver_email(self, value):
        self._receiver_email = value
    @property
    def receiver_mobile(self):
        return self._receiver_mobile

    @receiver_mobile.setter
    def receiver_mobile(self, value):
        self._receiver_mobile = value
    @property
    def receiver_name(self):
        return self._receiver_name

    @receiver_name.setter
    def receiver_name(self, value):
        self._receiver_name = value
    @property
    def receiver_state(self):
        return self._receiver_state

    @receiver_state.setter
    def receiver_state(self, value):
        self._receiver_state = value
    @property
    def receiver_zip(self):
        return self._receiver_zip

    @receiver_zip.setter
    def receiver_zip(self, value):
        self._receiver_zip = value
    @property
    def scene_code(self):
        return self._scene_code

    @scene_code.setter
    def scene_code(self, value):
        self._scene_code = value
    @property
    def seller_account_no(self):
        return self._seller_account_no

    @seller_account_no.setter
    def seller_account_no(self, value):
        self._seller_account_no = value
    @property
    def seller_bind_bankcard(self):
        return self._seller_bind_bankcard

    @seller_bind_bankcard.setter
    def seller_bind_bankcard(self, value):
        self._seller_bind_bankcard = value
    @property
    def seller_bind_bankcard_type(self):
        return self._seller_bind_bankcard_type

    @seller_bind_bankcard_type.setter
    def seller_bind_bankcard_type(self, value):
        self._seller_bind_bankcard_type = value
    @property
    def seller_bind_mobile(self):
        return self._seller_bind_mobile

    @seller_bind_mobile.setter
    def seller_bind_mobile(self, value):
        self._seller_bind_mobile = value
    @property
    def seller_identity_no(self):
        return self._seller_identity_no

    @seller_identity_no.setter
    def seller_identity_no(self, value):
        self._seller_identity_no = value
    @property
    def seller_identity_type(self):
        return self._seller_identity_type

    @seller_identity_type.setter
    def seller_identity_type(self, value):
        self._seller_identity_type = value
    @property
    def seller_real_name(self):
        return self._seller_real_name

    @seller_real_name.setter
    def seller_real_name(self, value):
        self._seller_real_name = value
    @property
    def seller_reg_date(self):
        return self._seller_reg_date

    @seller_reg_date.setter
    def seller_reg_date(self, value):
        self._seller_reg_date = value
    @property
    def seller_reg_email(self):
        return self._seller_reg_email

    @seller_reg_email.setter
    def seller_reg_email(self, value):
        self._seller_reg_email = value
    @property
    def seller_reg_moile(self):
        return self._seller_reg_moile

    @seller_reg_moile.setter
    def seller_reg_moile(self, value):
        self._seller_reg_moile = value
    @property
    def transport_type(self):
        return self._transport_type

    @transport_type.setter
    def transport_type(self, value):
        self._transport_type = value


    @property
    def version(self):
        return self._version

    @version.setter
    def version(self, value):
        self._version = value

    @property
    def terminal_type(self):
        return self._terminal_type

    @terminal_type.setter
    def terminal_type(self, value):
        self._terminal_type = value

    @property
    def terminal_info(self):
        return self._terminal_info

    @terminal_info.setter
    def terminal_info(self, value):
        self._terminal_info = value

    @property
    def prod_code(self):
        return self._prod_code

    @prod_code.setter
    def prod_code(self, value):
        self._prod_code = value

    @property
    def notify_url(self):
        return self._notify_url

    @notify_url.setter
    def notify_url(self, value):
        self._notify_url = value

    @property
    def return_url(self):
        return self._return_url

    @return_url.setter
    def return_url(self, value):
        self._return_url = value

    @property
    def udf_params(self):
        return self._udf_params

    @udf_params.setter
    def udf_params(self, value):
        if not isinstance(value, dict):
            return
        self._udf_params = value

    @property
    def need_encrypt(self):
        return self._need_encrypt

    @need_encrypt.setter
    def need_encrypt(self, value):
        self._need_encrypt = value

    def add_other_text_param(self, key, value):
        if not self.udf_params:
            self.udf_params = dict()
        self.udf_params[key] = value

    def get_params(self):
        params = dict()
        params[P_METHOD] = 'alipay.security.risk.detect'
        params[P_VERSION] = self.version
        if self.biz_model:
            params[P_BIZ_CONTENT] = json.dumps(obj=self.biz_model.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
        if self.buyer_account_no:
            if hasattr(self.buyer_account_no, 'to_alipay_dict'):
                params['buyer_account_no'] = json.dumps(obj=self.buyer_account_no.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['buyer_account_no'] = self.buyer_account_no
        if self.buyer_bind_bankcard:
            if hasattr(self.buyer_bind_bankcard, 'to_alipay_dict'):
                params['buyer_bind_bankcard'] = json.dumps(obj=self.buyer_bind_bankcard.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['buyer_bind_bankcard'] = self.buyer_bind_bankcard
        if self.buyer_bind_bankcard_type:
            if hasattr(self.buyer_bind_bankcard_type, 'to_alipay_dict'):
                params['buyer_bind_bankcard_type'] = json.dumps(obj=self.buyer_bind_bankcard_type.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['buyer_bind_bankcard_type'] = self.buyer_bind_bankcard_type
        if self.buyer_bind_mobile:
            if hasattr(self.buyer_bind_mobile, 'to_alipay_dict'):
                params['buyer_bind_mobile'] = json.dumps(obj=self.buyer_bind_mobile.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['buyer_bind_mobile'] = self.buyer_bind_mobile
        if self.buyer_grade:
            if hasattr(self.buyer_grade, 'to_alipay_dict'):
                params['buyer_grade'] = json.dumps(obj=self.buyer_grade.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['buyer_grade'] = self.buyer_grade
        if self.buyer_identity_no:
            if hasattr(self.buyer_identity_no, 'to_alipay_dict'):
                params['buyer_identity_no'] = json.dumps(obj=self.buyer_identity_no.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['buyer_identity_no'] = self.buyer_identity_no
        if self.buyer_identity_type:
            if hasattr(self.buyer_identity_type, 'to_alipay_dict'):
                params['buyer_identity_type'] = json.dumps(obj=self.buyer_identity_type.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['buyer_identity_type'] = self.buyer_identity_type
        if self.buyer_real_name:
            if hasattr(self.buyer_real_name, 'to_alipay_dict'):
                params['buyer_real_name'] = json.dumps(obj=self.buyer_real_name.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['buyer_real_name'] = self.buyer_real_name
        if self.buyer_reg_date:
            if hasattr(self.buyer_reg_date, 'to_alipay_dict'):
                params['buyer_reg_date'] = json.dumps(obj=self.buyer_reg_date.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['buyer_reg_date'] = self.buyer_reg_date
        if self.buyer_reg_email:
            if hasattr(self.buyer_reg_email, 'to_alipay_dict'):
                params['buyer_reg_email'] = json.dumps(obj=self.buyer_reg_email.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['buyer_reg_email'] = self.buyer_reg_email
        if self.buyer_reg_mobile:
            if hasattr(self.buyer_reg_mobile, 'to_alipay_dict'):
                params['buyer_reg_mobile'] = json.dumps(obj=self.buyer_reg_mobile.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['buyer_reg_mobile'] = self.buyer_reg_mobile
        if self.buyer_scene_bankcard:
            if hasattr(self.buyer_scene_bankcard, 'to_alipay_dict'):
                params['buyer_scene_bankcard'] = json.dumps(obj=self.buyer_scene_bankcard.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['buyer_scene_bankcard'] = self.buyer_scene_bankcard
        if self.buyer_scene_bankcard_type:
            if hasattr(self.buyer_scene_bankcard_type, 'to_alipay_dict'):
                params['buyer_scene_bankcard_type'] = json.dumps(obj=self.buyer_scene_bankcard_type.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['buyer_scene_bankcard_type'] = self.buyer_scene_bankcard_type
        if self.buyer_scene_email:
            if hasattr(self.buyer_scene_email, 'to_alipay_dict'):
                params['buyer_scene_email'] = json.dumps(obj=self.buyer_scene_email.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['buyer_scene_email'] = self.buyer_scene_email
        if self.buyer_scene_mobile:
            if hasattr(self.buyer_scene_mobile, 'to_alipay_dict'):
                params['buyer_scene_mobile'] = json.dumps(obj=self.buyer_scene_mobile.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['buyer_scene_mobile'] = self.buyer_scene_mobile
        if self.currency:
            if hasattr(self.currency, 'to_alipay_dict'):
                params['currency'] = json.dumps(obj=self.currency.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['currency'] = self.currency
        if self.env_client_base_band:
            if hasattr(self.env_client_base_band, 'to_alipay_dict'):
                params['env_client_base_band'] = json.dumps(obj=self.env_client_base_band.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['env_client_base_band'] = self.env_client_base_band
        if self.env_client_base_station:
            if hasattr(self.env_client_base_station, 'to_alipay_dict'):
                params['env_client_base_station'] = json.dumps(obj=self.env_client_base_station.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['env_client_base_station'] = self.env_client_base_station
        if self.env_client_coordinates:
            if hasattr(self.env_client_coordinates, 'to_alipay_dict'):
                params['env_client_coordinates'] = json.dumps(obj=self.env_client_coordinates.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['env_client_coordinates'] = self.env_client_coordinates
        if self.env_client_imei:
            if hasattr(self.env_client_imei, 'to_alipay_dict'):
                params['env_client_imei'] = json.dumps(obj=self.env_client_imei.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['env_client_imei'] = self.env_client_imei
        if self.env_client_imsi:
            if hasattr(self.env_client_imsi, 'to_alipay_dict'):
                params['env_client_imsi'] = json.dumps(obj=self.env_client_imsi.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['env_client_imsi'] = self.env_client_imsi
        if self.env_client_ios_udid:
            if hasattr(self.env_client_ios_udid, 'to_alipay_dict'):
                params['env_client_ios_udid'] = json.dumps(obj=self.env_client_ios_udid.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['env_client_ios_udid'] = self.env_client_ios_udid
        if self.env_client_ip:
            if hasattr(self.env_client_ip, 'to_alipay_dict'):
                params['env_client_ip'] = json.dumps(obj=self.env_client_ip.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['env_client_ip'] = self.env_client_ip
        if self.env_client_mac:
            if hasattr(self.env_client_mac, 'to_alipay_dict'):
                params['env_client_mac'] = json.dumps(obj=self.env_client_mac.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['env_client_mac'] = self.env_client_mac
        if self.env_client_screen:
            if hasattr(self.env_client_screen, 'to_alipay_dict'):
                params['env_client_screen'] = json.dumps(obj=self.env_client_screen.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['env_client_screen'] = self.env_client_screen
        if self.env_client_uuid:
            if hasattr(self.env_client_uuid, 'to_alipay_dict'):
                params['env_client_uuid'] = json.dumps(obj=self.env_client_uuid.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['env_client_uuid'] = self.env_client_uuid
        if self.item_quantity:
            if hasattr(self.item_quantity, 'to_alipay_dict'):
                params['item_quantity'] = json.dumps(obj=self.item_quantity.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['item_quantity'] = self.item_quantity
        if self.item_unit_price:
            if hasattr(self.item_unit_price, 'to_alipay_dict'):
                params['item_unit_price'] = json.dumps(obj=self.item_unit_price.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['item_unit_price'] = self.item_unit_price
        if self.js_token_id:
            if hasattr(self.js_token_id, 'to_alipay_dict'):
                params['js_token_id'] = json.dumps(obj=self.js_token_id.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['js_token_id'] = self.js_token_id
        if self.order_amount:
            if hasattr(self.order_amount, 'to_alipay_dict'):
                params['order_amount'] = json.dumps(obj=self.order_amount.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['order_amount'] = self.order_amount
        if self.order_category:
            if hasattr(self.order_category, 'to_alipay_dict'):
                params['order_category'] = json.dumps(obj=self.order_category.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['order_category'] = self.order_category
        if self.order_credate_time:
            if hasattr(self.order_credate_time, 'to_alipay_dict'):
                params['order_credate_time'] = json.dumps(obj=self.order_credate_time.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['order_credate_time'] = self.order_credate_time
        if self.order_item_city:
            if hasattr(self.order_item_city, 'to_alipay_dict'):
                params['order_item_city'] = json.dumps(obj=self.order_item_city.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['order_item_city'] = self.order_item_city
        if self.order_item_name:
            if hasattr(self.order_item_name, 'to_alipay_dict'):
                params['order_item_name'] = json.dumps(obj=self.order_item_name.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['order_item_name'] = self.order_item_name
        if self.order_no:
            if hasattr(self.order_no, 'to_alipay_dict'):
                params['order_no'] = json.dumps(obj=self.order_no.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['order_no'] = self.order_no
        if self.partner_id:
            if hasattr(self.partner_id, 'to_alipay_dict'):
                params['partner_id'] = json.dumps(obj=self.partner_id.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['partner_id'] = self.partner_id
        if self.receiver_address:
            if hasattr(self.receiver_address, 'to_alipay_dict'):
                params['receiver_address'] = json.dumps(obj=self.receiver_address.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['receiver_address'] = self.receiver_address
        if self.receiver_city:
            if hasattr(self.receiver_city, 'to_alipay_dict'):
                params['receiver_city'] = json.dumps(obj=self.receiver_city.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['receiver_city'] = self.receiver_city
        if self.receiver_district:
            if hasattr(self.receiver_district, 'to_alipay_dict'):
                params['receiver_district'] = json.dumps(obj=self.receiver_district.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['receiver_district'] = self.receiver_district
        if self.receiver_email:
            if hasattr(self.receiver_email, 'to_alipay_dict'):
                params['receiver_email'] = json.dumps(obj=self.receiver_email.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['receiver_email'] = self.receiver_email
        if self.receiver_mobile:
            if hasattr(self.receiver_mobile, 'to_alipay_dict'):
                params['receiver_mobile'] = json.dumps(obj=self.receiver_mobile.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['receiver_mobile'] = self.receiver_mobile
        if self.receiver_name:
            if hasattr(self.receiver_name, 'to_alipay_dict'):
                params['receiver_name'] = json.dumps(obj=self.receiver_name.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['receiver_name'] = self.receiver_name
        if self.receiver_state:
            if hasattr(self.receiver_state, 'to_alipay_dict'):
                params['receiver_state'] = json.dumps(obj=self.receiver_state.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['receiver_state'] = self.receiver_state
        if self.receiver_zip:
            if hasattr(self.receiver_zip, 'to_alipay_dict'):
                params['receiver_zip'] = json.dumps(obj=self.receiver_zip.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['receiver_zip'] = self.receiver_zip
        if self.scene_code:
            if hasattr(self.scene_code, 'to_alipay_dict'):
                params['scene_code'] = json.dumps(obj=self.scene_code.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['scene_code'] = self.scene_code
        if self.seller_account_no:
            if hasattr(self.seller_account_no, 'to_alipay_dict'):
                params['seller_account_no'] = json.dumps(obj=self.seller_account_no.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['seller_account_no'] = self.seller_account_no
        if self.seller_bind_bankcard:
            if hasattr(self.seller_bind_bankcard, 'to_alipay_dict'):
                params['seller_bind_bankcard'] = json.dumps(obj=self.seller_bind_bankcard.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['seller_bind_bankcard'] = self.seller_bind_bankcard
        if self.seller_bind_bankcard_type:
            if hasattr(self.seller_bind_bankcard_type, 'to_alipay_dict'):
                params['seller_bind_bankcard_type'] = json.dumps(obj=self.seller_bind_bankcard_type.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['seller_bind_bankcard_type'] = self.seller_bind_bankcard_type
        if self.seller_bind_mobile:
            if hasattr(self.seller_bind_mobile, 'to_alipay_dict'):
                params['seller_bind_mobile'] = json.dumps(obj=self.seller_bind_mobile.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['seller_bind_mobile'] = self.seller_bind_mobile
        if self.seller_identity_no:
            if hasattr(self.seller_identity_no, 'to_alipay_dict'):
                params['seller_identity_no'] = json.dumps(obj=self.seller_identity_no.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['seller_identity_no'] = self.seller_identity_no
        if self.seller_identity_type:
            if hasattr(self.seller_identity_type, 'to_alipay_dict'):
                params['seller_identity_type'] = json.dumps(obj=self.seller_identity_type.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['seller_identity_type'] = self.seller_identity_type
        if self.seller_real_name:
            if hasattr(self.seller_real_name, 'to_alipay_dict'):
                params['seller_real_name'] = json.dumps(obj=self.seller_real_name.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['seller_real_name'] = self.seller_real_name
        if self.seller_reg_date:
            if hasattr(self.seller_reg_date, 'to_alipay_dict'):
                params['seller_reg_date'] = json.dumps(obj=self.seller_reg_date.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['seller_reg_date'] = self.seller_reg_date
        if self.seller_reg_email:
            if hasattr(self.seller_reg_email, 'to_alipay_dict'):
                params['seller_reg_email'] = json.dumps(obj=self.seller_reg_email.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['seller_reg_email'] = self.seller_reg_email
        if self.seller_reg_moile:
            if hasattr(self.seller_reg_moile, 'to_alipay_dict'):
                params['seller_reg_moile'] = json.dumps(obj=self.seller_reg_moile.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['seller_reg_moile'] = self.seller_reg_moile
        if self.transport_type:
            if hasattr(self.transport_type, 'to_alipay_dict'):
                params['transport_type'] = json.dumps(obj=self.transport_type.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['transport_type'] = self.transport_type
        if self.terminal_type:
            params['terminal_type'] = self.terminal_type
        if self.terminal_info:
            params['terminal_info'] = self.terminal_info
        if self.prod_code:
            params['prod_code'] = self.prod_code
        if self.notify_url:
            params['notify_url'] = self.notify_url
        if self.return_url:
            params['return_url'] = self.return_url
        if self.udf_params:
            params.update(self.udf_params)
        return params

    def get_multipart_params(self):
        multipart_params = dict()
        return multipart_params



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.CaSystemCrossPageRequest import CaSystemCrossPageRequest
from alipay.aop.api.domain.CaSystemMainBodyRequest import CaSystemMainBodyRequest


class CaSystemSignAreaRequest(object):

    def __init__(self):
        self._ca_system_cross_page_request = None
        self._ca_system_main_body_request = None
        self._location_type = None
        self._position_type = None
        self._seal_id = None

    @property
    def ca_system_cross_page_request(self):
        return self._ca_system_cross_page_request

    @ca_system_cross_page_request.setter
    def ca_system_cross_page_request(self, value):
        if isinstance(value, CaSystemCrossPageRequest):
            self._ca_system_cross_page_request = value
        else:
            self._ca_system_cross_page_request = CaSystemCrossPageRequest.from_alipay_dict(value)
    @property
    def ca_system_main_body_request(self):
        return self._ca_system_main_body_request

    @ca_system_main_body_request.setter
    def ca_system_main_body_request(self, value):
        if isinstance(value, CaSystemMainBodyRequest):
            self._ca_system_main_body_request = value
        else:
            self._ca_system_main_body_request = CaSystemMainBodyRequest.from_alipay_dict(value)
    @property
    def location_type(self):
        return self._location_type

    @location_type.setter
    def location_type(self, value):
        self._location_type = value
    @property
    def position_type(self):
        return self._position_type

    @position_type.setter
    def position_type(self, value):
        self._position_type = value
    @property
    def seal_id(self):
        return self._seal_id

    @seal_id.setter
    def seal_id(self, value):
        self._seal_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.ca_system_cross_page_request:
            if hasattr(self.ca_system_cross_page_request, 'to_alipay_dict'):
                params['ca_system_cross_page_request'] = self.ca_system_cross_page_request.to_alipay_dict()
            else:
                params['ca_system_cross_page_request'] = self.ca_system_cross_page_request
        if self.ca_system_main_body_request:
            if hasattr(self.ca_system_main_body_request, 'to_alipay_dict'):
                params['ca_system_main_body_request'] = self.ca_system_main_body_request.to_alipay_dict()
            else:
                params['ca_system_main_body_request'] = self.ca_system_main_body_request
        if self.location_type:
            if hasattr(self.location_type, 'to_alipay_dict'):
                params['location_type'] = self.location_type.to_alipay_dict()
            else:
                params['location_type'] = self.location_type
        if self.position_type:
            if hasattr(self.position_type, 'to_alipay_dict'):
                params['position_type'] = self.position_type.to_alipay_dict()
            else:
                params['position_type'] = self.position_type
        if self.seal_id:
            if hasattr(self.seal_id, 'to_alipay_dict'):
                params['seal_id'] = self.seal_id.to_alipay_dict()
            else:
                params['seal_id'] = self.seal_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = CaSystemSignAreaRequest()
        if 'ca_system_cross_page_request' in d:
            o.ca_system_cross_page_request = d['ca_system_cross_page_request']
        if 'ca_system_main_body_request' in d:
            o.ca_system_main_body_request = d['ca_system_main_body_request']
        if 'location_type' in d:
            o.location_type = d['location_type']
        if 'position_type' in d:
            o.position_type = d['position_type']
        if 'seal_id' in d:
            o.seal_id = d['seal_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.Scene import Scene


class CodeInfo(object):

    def __init__(self):
        self._goto_url = None
        self._scene = None

    @property
    def goto_url(self):
        return self._goto_url

    @goto_url.setter
    def goto_url(self, value):
        self._goto_url = value
    @property
    def scene(self):
        return self._scene

    @scene.setter
    def scene(self, value):
        if isinstance(value, Scene):
            self._scene = value
        else:
            self._scene = Scene.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.goto_url:
            if hasattr(self.goto_url, 'to_alipay_dict'):
                params['goto_url'] = self.goto_url.to_alipay_dict()
            else:
                params['goto_url'] = self.goto_url
        if self.scene:
            if hasattr(self.scene, 'to_alipay_dict'):
                params['scene'] = self.scene.to_alipay_dict()
            else:
                params['scene'] = self.scene
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = CodeInfo()
        if 'goto_url' in d:
            o.goto_url = d['goto_url']
        if 'scene' in d:
            o.scene = d['scene']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class BusinessWebAppDTO(object):

    def __init__(self):
        self._account = None
        self._app_status = None
        self._app_type = None
        self._ext_pictures = None
        self._icp_auth_pic = None
        self._icp_licence_pic = None
        self._memo = None
        self._password = None
        self._screenshot = None
        self._url = None

    @property
    def account(self):
        return self._account

    @account.setter
    def account(self, value):
        self._account = value
    @property
    def app_status(self):
        return self._app_status

    @app_status.setter
    def app_status(self, value):
        self._app_status = value
    @property
    def app_type(self):
        return self._app_type

    @app_type.setter
    def app_type(self, value):
        self._app_type = value
    @property
    def ext_pictures(self):
        return self._ext_pictures

    @ext_pictures.setter
    def ext_pictures(self, value):
        if isinstance(value, list):
            self._ext_pictures = list()
            for i in value:
                self._ext_pictures.append(i)
    @property
    def icp_auth_pic(self):
        return self._icp_auth_pic

    @icp_auth_pic.setter
    def icp_auth_pic(self, value):
        self._icp_auth_pic = value
    @property
    def icp_licence_pic(self):
        return self._icp_licence_pic

    @icp_licence_pic.setter
    def icp_licence_pic(self, value):
        self._icp_licence_pic = value
    @property
    def memo(self):
        return self._memo

    @memo.setter
    def memo(self, value):
        self._memo = value
    @property
    def password(self):
        return self._password

    @password.setter
    def password(self, value):
        self._password = value
    @property
    def screenshot(self):
        return self._screenshot

    @screenshot.setter
    def screenshot(self, value):
        if isinstance(value, list):
            self._screenshot = list()
            for i in value:
                self._screenshot.append(i)
    @property
    def url(self):
        return self._url

    @url.setter
    def url(self, value):
        self._url = value


    def to_alipay_dict(self):
        params = dict()
        if self.account:
            if hasattr(self.account, 'to_alipay_dict'):
                params['account'] = self.account.to_alipay_dict()
            else:
                params['account'] = self.account
        if self.app_status:
            if hasattr(self.app_status, 'to_alipay_dict'):
                params['app_status'] = self.app_status.to_alipay_dict()
            else:
                params['app_status'] = self.app_status
        if self.app_type:
            if hasattr(self.app_type, 'to_alipay_dict'):
                params['app_type'] = self.app_type.to_alipay_dict()
            else:
                params['app_type'] = self.app_type
        if self.ext_pictures:
            if isinstance(self.ext_pictures, list):
                for i in range(0, len(self.ext_pictures)):
                    element = self.ext_pictures[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.ext_pictures[i] = element.to_alipay_dict()
            if hasattr(self.ext_pictures, 'to_alipay_dict'):
                params['ext_pictures'] = self.ext_pictures.to_alipay_dict()
            else:
                params['ext_pictures'] = self.ext_pictures
        if self.icp_auth_pic:
            if hasattr(self.icp_auth_pic, 'to_alipay_dict'):
                params['icp_auth_pic'] = self.icp_auth_pic.to_alipay_dict()
            else:
                params['icp_auth_pic'] = self.icp_auth_pic
        if self.icp_licence_pic:
            if hasattr(self.icp_licence_pic, 'to_alipay_dict'):
                params['icp_licence_pic'] = self.icp_licence_pic.to_alipay_dict()
            else:
                params['icp_licence_pic'] = self.icp_licence_pic
        if self.memo:
            if hasattr(self.memo, 'to_alipay_dict'):
                params['memo'] = self.memo.to_alipay_dict()
            else:
                params['memo'] = self.memo
        if self.password:
            if hasattr(self.password, 'to_alipay_dict'):
                params['password'] = self.password.to_alipay_dict()
            else:
                params['password'] = self.password
        if self.screenshot:
            if isinstance(self.screenshot, list):
                for i in range(0, len(self.screenshot)):
                    element = self.screenshot[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.screenshot[i] = element.to_alipay_dict()
            if hasattr(self.screenshot, 'to_alipay_dict'):
                params['screenshot'] = self.screenshot.to_alipay_dict()
            else:
                params['screenshot'] = self.screenshot
        if self.url:
            if hasattr(self.url, 'to_alipay_dict'):
                params['url'] = self.url.to_alipay_dict()
            else:
                params['url'] = self.url
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = BusinessWebAppDTO()
        if 'account' in d:
            o.account = d['account']
        if 'app_status' in d:
            o.app_status = d['app_status']
        if 'app_type' in d:
            o.app_type = d['app_type']
        if 'ext_pictures' in d:
            o.ext_pictures = d['ext_pictures']
        if 'icp_auth_pic' in d:
            o.icp_auth_pic = d['icp_auth_pic']
        if 'icp_licence_pic' in d:
            o.icp_licence_pic = d['icp_licence_pic']
        if 'memo' in d:
            o.memo = d['memo']
        if 'password' in d:
            o.password = d['password']
        if 'screenshot' in d:
            o.screenshot = d['screenshot']
        if 'url' in d:
            o.url = d['url']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.TradeFundBill import TradeFundBill


class PaytoolRefundResultDetail(object):

    def __init__(self):
        self._gmt_refund = None
        self._paytool_bill_no = None
        self._paytool_request_no = None
        self._refund_amount = None
        self._refund_fund_bill_list = None
        self._status = None
        self._tool_code = None

    @property
    def gmt_refund(self):
        return self._gmt_refund

    @gmt_refund.setter
    def gmt_refund(self, value):
        self._gmt_refund = value
    @property
    def paytool_bill_no(self):
        return self._paytool_bill_no

    @paytool_bill_no.setter
    def paytool_bill_no(self, value):
        self._paytool_bill_no = value
    @property
    def paytool_request_no(self):
        return self._paytool_request_no

    @paytool_request_no.setter
    def paytool_request_no(self, value):
        self._paytool_request_no = value
    @property
    def refund_amount(self):
        return self._refund_amount

    @refund_amount.setter
    def refund_amount(self, value):
        self._refund_amount = value
    @property
    def refund_fund_bill_list(self):
        return self._refund_fund_bill_list

    @refund_fund_bill_list.setter
    def refund_fund_bill_list(self, value):
        if isinstance(value, list):
            self._refund_fund_bill_list = list()
            for i in value:
                if isinstance(i, TradeFundBill):
                    self._refund_fund_bill_list.append(i)
                else:
                    self._refund_fund_bill_list.append(TradeFundBill.from_alipay_dict(i))
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def tool_code(self):
        return self._tool_code

    @tool_code.setter
    def tool_code(self, value):
        self._tool_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.gmt_refund:
            if hasattr(self.gmt_refund, 'to_alipay_dict'):
                params['gmt_refund'] = self.gmt_refund.to_alipay_dict()
            else:
                params['gmt_refund'] = self.gmt_refund
        if self.paytool_bill_no:
            if hasattr(self.paytool_bill_no, 'to_alipay_dict'):
                params['paytool_bill_no'] = self.paytool_bill_no.to_alipay_dict()
            else:
                params['paytool_bill_no'] = self.paytool_bill_no
        if self.paytool_request_no:
            if hasattr(self.paytool_request_no, 'to_alipay_dict'):
                params['paytool_request_no'] = self.paytool_request_no.to_alipay_dict()
            else:
                params['paytool_request_no'] = self.paytool_request_no
        if self.refund_amount:
            if hasattr(self.refund_amount, 'to_alipay_dict'):
                params['refund_amount'] = self.refund_amount.to_alipay_dict()
            else:
                params['refund_amount'] = self.refund_amount
        if self.refund_fund_bill_list:
            if isinstance(self.refund_fund_bill_list, list):
                for i in range(0, len(self.refund_fund_bill_list)):
                    element = self.refund_fund_bill_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.refund_fund_bill_list[i] = element.to_alipay_dict()
            if hasattr(self.refund_fund_bill_list, 'to_alipay_dict'):
                params['refund_fund_bill_list'] = self.refund_fund_bill_list.to_alipay_dict()
            else:
                params['refund_fund_bill_list'] = self.refund_fund_bill_list
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        if self.tool_code:
            if hasattr(self.tool_code, 'to_alipay_dict'):
                params['tool_code'] = self.tool_code.to_alipay_dict()
            else:
                params['tool_code'] = self.tool_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = PaytoolRefundResultDetail()
        if 'gmt_refund' in d:
            o.gmt_refund = d['gmt_refund']
        if 'paytool_bill_no' in d:
            o.paytool_bill_no = d['paytool_bill_no']
        if 'paytool_request_no' in d:
            o.paytool_request_no = d['paytool_request_no']
        if 'refund_amount' in d:
            o.refund_amount = d['refund_amount']
        if 'refund_fund_bill_list' in d:
            o.refund_fund_bill_list = d['refund_fund_bill_list']
        if 'status' in d:
            o.status = d['status']
        if 'tool_code' in d:
            o.tool_code = d['tool_code']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.StuffStockInOrderItem import StuffStockInOrderItem


class StuffStockInOrder(object):

    def __init__(self):
        self._erp_order = None
        self._erp_order_type = None
        self._ext_info = None
        self._order_items = None
        self._scheduled_receipt_date = None
        self._warehouse_code = None

    @property
    def erp_order(self):
        return self._erp_order

    @erp_order.setter
    def erp_order(self, value):
        self._erp_order = value
    @property
    def erp_order_type(self):
        return self._erp_order_type

    @erp_order_type.setter
    def erp_order_type(self, value):
        self._erp_order_type = value
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        self._ext_info = value
    @property
    def order_items(self):
        return self._order_items

    @order_items.setter
    def order_items(self, value):
        if isinstance(value, list):
            self._order_items = list()
            for i in value:
                if isinstance(i, StuffStockInOrderItem):
                    self._order_items.append(i)
                else:
                    self._order_items.append(StuffStockInOrderItem.from_alipay_dict(i))
    @property
    def scheduled_receipt_date(self):
        return self._scheduled_receipt_date

    @scheduled_receipt_date.setter
    def scheduled_receipt_date(self, value):
        self._scheduled_receipt_date = value
    @property
    def warehouse_code(self):
        return self._warehouse_code

    @warehouse_code.setter
    def warehouse_code(self, value):
        self._warehouse_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.erp_order:
            if hasattr(self.erp_order, 'to_alipay_dict'):
                params['erp_order'] = self.erp_order.to_alipay_dict()
            else:
                params['erp_order'] = self.erp_order
        if self.erp_order_type:
            if hasattr(self.erp_order_type, 'to_alipay_dict'):
                params['erp_order_type'] = self.erp_order_type.to_alipay_dict()
            else:
                params['erp_order_type'] = self.erp_order_type
        if self.ext_info:
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.order_items:
            if isinstance(self.order_items, list):
                for i in range(0, len(self.order_items)):
                    element = self.order_items[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.order_items[i] = element.to_alipay_dict()
            if hasattr(self.order_items, 'to_alipay_dict'):
                params['order_items'] = self.order_items.to_alipay_dict()
            else:
                params['order_items'] = self.order_items
        if self.scheduled_receipt_date:
            if hasattr(self.scheduled_receipt_date, 'to_alipay_dict'):
                params['scheduled_receipt_date'] = self.scheduled_receipt_date.to_alipay_dict()
            else:
                params['scheduled_receipt_date'] = self.scheduled_receipt_date
        if self.warehouse_code:
            if hasattr(self.warehouse_code, 'to_alipay_dict'):
                params['warehouse_code'] = self.warehouse_code.to_alipay_dict()
            else:
                params['warehouse_code'] = self.warehouse_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = StuffStockInOrder()
        if 'erp_order' in d:
            o.erp_order = d['erp_order']
        if 'erp_order_type' in d:
            o.erp_order_type = d['erp_order_type']
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'order_items' in d:
            o.order_items = d['order_items']
        if 'scheduled_receipt_date' in d:
            o.scheduled_receipt_date = d['scheduled_receipt_date']
        if 'warehouse_code' in d:
            o.warehouse_code = d['warehouse_code']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class MiniAppHistoryInfo(object):

    def __init__(self):
        self._ext_info = None
        self._icon_url = None
        self._link = None
        self._mini_app_id = None
        self._name = None
        self._slogan = None

    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        self._ext_info = value
    @property
    def icon_url(self):
        return self._icon_url

    @icon_url.setter
    def icon_url(self, value):
        self._icon_url = value
    @property
    def link(self):
        return self._link

    @link.setter
    def link(self, value):
        self._link = value
    @property
    def mini_app_id(self):
        return self._mini_app_id

    @mini_app_id.setter
    def mini_app_id(self, value):
        self._mini_app_id = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def slogan(self):
        return self._slogan

    @slogan.setter
    def slogan(self, value):
        self._slogan = value


    def to_alipay_dict(self):
        params = dict()
        if self.ext_info:
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.icon_url:
            if hasattr(self.icon_url, 'to_alipay_dict'):
                params['icon_url'] = self.icon_url.to_alipay_dict()
            else:
                params['icon_url'] = self.icon_url
        if self.link:
            if hasattr(self.link, 'to_alipay_dict'):
                params['link'] = self.link.to_alipay_dict()
            else:
                params['link'] = self.link
        if self.mini_app_id:
            if hasattr(self.mini_app_id, 'to_alipay_dict'):
                params['mini_app_id'] = self.mini_app_id.to_alipay_dict()
            else:
                params['mini_app_id'] = self.mini_app_id
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        if self.slogan:
            if hasattr(self.slogan, 'to_alipay_dict'):
                params['slogan'] = self.slogan.to_alipay_dict()
            else:
                params['slogan'] = self.slogan
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MiniAppHistoryInfo()
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'icon_url' in d:
            o.icon_url = d['icon_url']
        if 'link' in d:
            o.link = d['link']
        if 'mini_app_id' in d:
            o.mini_app_id = d['mini_app_id']
        if 'name' in d:
            o.name = d['name']
        if 'slogan' in d:
            o.slogan = d['slogan']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class KoubeiRetailWmsOutboundorderQueryModel(object):

    def __init__(self):
        self._need_detail = None
        self._out_biz_no = None
        self._outbound_order_id = None

    @property
    def need_detail(self):
        return self._need_detail

    @need_detail.setter
    def need_detail(self, value):
        self._need_detail = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def outbound_order_id(self):
        return self._outbound_order_id

    @outbound_order_id.setter
    def outbound_order_id(self, value):
        self._outbound_order_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.need_detail:
            if hasattr(self.need_detail, 'to_alipay_dict'):
                params['need_detail'] = self.need_detail.to_alipay_dict()
            else:
                params['need_detail'] = self.need_detail
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.outbound_order_id:
            if hasattr(self.outbound_order_id, 'to_alipay_dict'):
                params['outbound_order_id'] = self.outbound_order_id.to_alipay_dict()
            else:
                params['outbound_order_id'] = self.outbound_order_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiRetailWmsOutboundorderQueryModel()
        if 'need_detail' in d:
            o.need_detail = d['need_detail']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'outbound_order_id' in d:
            o.outbound_order_id = d['outbound_order_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayPcreditHuabeiAuthAgreementQueryModel(object):

    def __init__(self):
        self._agreement_no = None
        self._alipay_user_id = None
        self._auth_scene = None
        self._open_id = None
        self._out_sign_no = None

    @property
    def agreement_no(self):
        return self._agreement_no

    @agreement_no.setter
    def agreement_no(self, value):
        self._agreement_no = value
    @property
    def alipay_user_id(self):
        return self._alipay_user_id

    @alipay_user_id.setter
    def alipay_user_id(self, value):
        self._alipay_user_id = value
    @property
    def auth_scene(self):
        return self._auth_scene

    @auth_scene.setter
    def auth_scene(self, value):
        self._auth_scene = value
    @property
    def open_id(self):
        return self._open_id

    @open_id.setter
    def open_id(self, value):
        self._open_id = value
    @property
    def out_sign_no(self):
        return self._out_sign_no

    @out_sign_no.setter
    def out_sign_no(self, value):
        self._out_sign_no = value


    def to_alipay_dict(self):
        params = dict()
        if self.agreement_no:
            if hasattr(self.agreement_no, 'to_alipay_dict'):
                params['agreement_no'] = self.agreement_no.to_alipay_dict()
            else:
                params['agreement_no'] = self.agreement_no
        if self.alipay_user_id:
            if hasattr(self.alipay_user_id, 'to_alipay_dict'):
                params['alipay_user_id'] = self.alipay_user_id.to_alipay_dict()
            else:
                params['alipay_user_id'] = self.alipay_user_id
        if self.auth_scene:
            if hasattr(self.auth_scene, 'to_alipay_dict'):
                params['auth_scene'] = self.auth_scene.to_alipay_dict()
            else:
                params['auth_scene'] = self.auth_scene
        if self.open_id:
            if hasattr(self.open_id, 'to_alipay_dict'):
                params['open_id'] = self.open_id.to_alipay_dict()
            else:
                params['open_id'] = self.open_id
        if self.out_sign_no:
            if hasattr(self.out_sign_no, 'to_alipay_dict'):
                params['out_sign_no'] = self.out_sign_no.to_alipay_dict()
            else:
                params['out_sign_no'] = self.out_sign_no
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayPcreditHuabeiAuthAgreementQueryModel()
        if 'agreement_no' in d:
            o.agreement_no = d['agreement_no']
        if 'alipay_user_id' in d:
            o.alipay_user_id = d['alipay_user_id']
        if 'auth_scene' in d:
            o.auth_scene = d['auth_scene']
        if 'open_id' in d:
            o.open_id = d['open_id']
        if 'out_sign_no' in d:
            o.out_sign_no = d['out_sign_no']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.InsPreOrderDTO import InsPreOrderDTO


class AlipayInsSceneEcommercePreorderQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayInsSceneEcommercePreorderQueryResponse, self).__init__()
        self._pre_orders = None

    @property
    def pre_orders(self):
        return self._pre_orders

    @pre_orders.setter
    def pre_orders(self, value):
        if isinstance(value, list):
            self._pre_orders = list()
            for i in value:
                if isinstance(i, InsPreOrderDTO):
                    self._pre_orders.append(i)
                else:
                    self._pre_orders.append(InsPreOrderDTO.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AlipayInsSceneEcommercePreorderQueryResponse, self).parse_response_content(response_content)
        if 'pre_orders' in response:
            self.pre_orders = response['pre_orders']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class KbdishSpecGroupDetail(object):

    def __init__(self):
        self._spec_id = None
        self._spec_name = None

    @property
    def spec_id(self):
        return self._spec_id

    @spec_id.setter
    def spec_id(self, value):
        self._spec_id = value
    @property
    def spec_name(self):
        return self._spec_name

    @spec_name.setter
    def spec_name(self, value):
        self._spec_name = value


    def to_alipay_dict(self):
        params = dict()
        if self.spec_id:
            if hasattr(self.spec_id, 'to_alipay_dict'):
                params['spec_id'] = self.spec_id.to_alipay_dict()
            else:
                params['spec_id'] = self.spec_id
        if self.spec_name:
            if hasattr(self.spec_name, 'to_alipay_dict'):
                params['spec_name'] = self.spec_name.to_alipay_dict()
            else:
                params['spec_name'] = self.spec_name
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KbdishSpecGroupDetail()
        if 'spec_id' in d:
            o.spec_id = d['spec_id']
        if 'spec_name' in d:
            o.spec_name = d['spec_name']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceTransportParkingGoodsModifyModel(object):

    def __init__(self):
        self._arg_date_week = None
        self._arg_end_time = None
        self._arg_start_time = None
        self._biz_data = None
        self._cost_price = None
        self._count_num = None
        self._current_price = None
        self._date_num = None
        self._desc = None
        self._end_sell_time = None
        self._goods_id = None
        self._goods_num = None
        self._keywords = None
        self._name = None
        self._out_id = None
        self._parking_id = None
        self._put_time = None
        self._start_sell_time = None

    @property
    def arg_date_week(self):
        return self._arg_date_week

    @arg_date_week.setter
    def arg_date_week(self, value):
        self._arg_date_week = value
    @property
    def arg_end_time(self):
        return self._arg_end_time

    @arg_end_time.setter
    def arg_end_time(self, value):
        self._arg_end_time = value
    @property
    def arg_start_time(self):
        return self._arg_start_time

    @arg_start_time.setter
    def arg_start_time(self, value):
        self._arg_start_time = value
    @property
    def biz_data(self):
        return self._biz_data

    @biz_data.setter
    def biz_data(self, value):
        self._biz_data = value
    @property
    def cost_price(self):
        return self._cost_price

    @cost_price.setter
    def cost_price(self, value):
        self._cost_price = value
    @property
    def count_num(self):
        return self._count_num

    @count_num.setter
    def count_num(self, value):
        self._count_num = value
    @property
    def current_price(self):
        return self._current_price

    @current_price.setter
    def current_price(self, value):
        self._current_price = value
    @property
    def date_num(self):
        return self._date_num

    @date_num.setter
    def date_num(self, value):
        self._date_num = value
    @property
    def desc(self):
        return self._desc

    @desc.setter
    def desc(self, value):
        self._desc = value
    @property
    def end_sell_time(self):
        return self._end_sell_time

    @end_sell_time.setter
    def end_sell_time(self, value):
        self._end_sell_time = value
    @property
    def goods_id(self):
        return self._goods_id

    @goods_id.setter
    def goods_id(self, value):
        self._goods_id = value
    @property
    def goods_num(self):
        return self._goods_num

    @goods_num.setter
    def goods_num(self, value):
        self._goods_num = value
    @property
    def keywords(self):
        return self._keywords

    @keywords.setter
    def keywords(self, value):
        self._keywords = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def out_id(self):
        return self._out_id

    @out_id.setter
    def out_id(self, value):
        self._out_id = value
    @property
    def parking_id(self):
        return self._parking_id

    @parking_id.setter
    def parking_id(self, value):
        self._parking_id = value
    @property
    def put_time(self):
        return self._put_time

    @put_time.setter
    def put_time(self, value):
        self._put_time = value
    @property
    def start_sell_time(self):
        return self._start_sell_time

    @start_sell_time.setter
    def start_sell_time(self, value):
        self._start_sell_time = value


    def to_alipay_dict(self):
        params = dict()
        if self.arg_date_week:
            if hasattr(self.arg_date_week, 'to_alipay_dict'):
                params['arg_date_week'] = self.arg_date_week.to_alipay_dict()
            else:
                params['arg_date_week'] = self.arg_date_week
        if self.arg_end_time:
            if hasattr(self.arg_end_time, 'to_alipay_dict'):
                params['arg_end_time'] = self.arg_end_time.to_alipay_dict()
            else:
                params['arg_end_time'] = self.arg_end_time
        if self.arg_start_time:
            if hasattr(self.arg_start_time, 'to_alipay_dict'):
                params['arg_start_time'] = self.arg_start_time.to_alipay_dict()
            else:
                params['arg_start_time'] = self.arg_start_time
        if self.biz_data:
            if hasattr(self.biz_data, 'to_alipay_dict'):
                params['biz_data'] = self.biz_data.to_alipay_dict()
            else:
                params['biz_data'] = self.biz_data
        if self.cost_price:
            if hasattr(self.cost_price, 'to_alipay_dict'):
                params['cost_price'] = self.cost_price.to_alipay_dict()
            else:
                params['cost_price'] = self.cost_price
        if self.count_num:
            if hasattr(self.count_num, 'to_alipay_dict'):
                params['count_num'] = self.count_num.to_alipay_dict()
            else:
                params['count_num'] = self.count_num
        if self.current_price:
            if hasattr(self.current_price, 'to_alipay_dict'):
                params['current_price'] = self.current_price.to_alipay_dict()
            else:
                params['current_price'] = self.current_price
        if self.date_num:
            if hasattr(self.date_num, 'to_alipay_dict'):
                params['date_num'] = self.date_num.to_alipay_dict()
            else:
                params['date_num'] = self.date_num
        if self.desc:
            if hasattr(self.desc, 'to_alipay_dict'):
                params['desc'] = self.desc.to_alipay_dict()
            else:
                params['desc'] = self.desc
        if self.end_sell_time:
            if hasattr(self.end_sell_time, 'to_alipay_dict'):
                params['end_sell_time'] = self.end_sell_time.to_alipay_dict()
            else:
                params['end_sell_time'] = self.end_sell_time
        if self.goods_id:
            if hasattr(self.goods_id, 'to_alipay_dict'):
                params['goods_id'] = self.goods_id.to_alipay_dict()
            else:
                params['goods_id'] = self.goods_id
        if self.goods_num:
            if hasattr(self.goods_num, 'to_alipay_dict'):
                params['goods_num'] = self.goods_num.to_alipay_dict()
            else:
                params['goods_num'] = self.goods_num
        if self.keywords:
            if hasattr(self.keywords, 'to_alipay_dict'):
                params['keywords'] = self.keywords.to_alipay_dict()
            else:
                params['keywords'] = self.keywords
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        if self.out_id:
            if hasattr(self.out_id, 'to_alipay_dict'):
                params['out_id'] = self.out_id.to_alipay_dict()
            else:
                params['out_id'] = self.out_id
        if self.parking_id:
            if hasattr(self.parking_id, 'to_alipay_dict'):
                params['parking_id'] = self.parking_id.to_alipay_dict()
            else:
                params['parking_id'] = self.parking_id
        if self.put_time:
            if hasattr(self.put_time, 'to_alipay_dict'):
                params['put_time'] = self.put_time.to_alipay_dict()
            else:
                params['put_time'] = self.put_time
        if self.start_sell_time:
            if hasattr(self.start_sell_time, 'to_alipay_dict'):
                params['start_sell_time'] = self.start_sell_time.to_alipay_dict()
            else:
                params['start_sell_time'] = self.start_sell_time
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceTransportParkingGoodsModifyModel()
        if 'arg_date_week' in d:
            o.arg_date_week = d['arg_date_week']
        if 'arg_end_time' in d:
            o.arg_end_time = d['arg_end_time']
        if 'arg_start_time' in d:
            o.arg_start_time = d['arg_start_time']
        if 'biz_data' in d:
            o.biz_data = d['biz_data']
        if 'cost_price' in d:
            o.cost_price = d['cost_price']
        if 'count_num' in d:
            o.count_num = d['count_num']
        if 'current_price' in d:
            o.current_price = d['current_price']
        if 'date_num' in d:
            o.date_num = d['date_num']
        if 'desc' in d:
            o.desc = d['desc']
        if 'end_sell_time' in d:
            o.end_sell_time = d['end_sell_time']
        if 'goods_id' in d:
            o.goods_id = d['goods_id']
        if 'goods_num' in d:
            o.goods_num = d['goods_num']
        if 'keywords' in d:
            o.keywords = d['keywords']
        if 'name' in d:
            o.name = d['name']
        if 'out_id' in d:
            o.out_id = d['out_id']
        if 'parking_id' in d:
            o.parking_id = d['parking_id']
        if 'put_time' in d:
            o.put_time = d['put_time']
        if 'start_sell_time' in d:
            o.start_sell_time = d['start_sell_time']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class BoxExclusiveServiceOpenApiInfos(object):

    def __init__(self):
        self._appid = None
        self._catalog_id = None
        self._catalog_name = None
        self._sepc_code = None
        self._service_code = None
        self._service_logo = None
        self._service_name = None

    @property
    def appid(self):
        return self._appid

    @appid.setter
    def appid(self, value):
        self._appid = value
    @property
    def catalog_id(self):
        return self._catalog_id

    @catalog_id.setter
    def catalog_id(self, value):
        self._catalog_id = value
    @property
    def catalog_name(self):
        return self._catalog_name

    @catalog_name.setter
    def catalog_name(self, value):
        self._catalog_name = value
    @property
    def sepc_code(self):
        return self._sepc_code

    @sepc_code.setter
    def sepc_code(self, value):
        self._sepc_code = value
    @property
    def service_code(self):
        return self._service_code

    @service_code.setter
    def service_code(self, value):
        self._service_code = value
    @property
    def service_logo(self):
        return self._service_logo

    @service_logo.setter
    def service_logo(self, value):
        self._service_logo = value
    @property
    def service_name(self):
        return self._service_name

    @service_name.setter
    def service_name(self, value):
        self._service_name = value


    def to_alipay_dict(self):
        params = dict()
        if self.appid:
            if hasattr(self.appid, 'to_alipay_dict'):
                params['appid'] = self.appid.to_alipay_dict()
            else:
                params['appid'] = self.appid
        if self.catalog_id:
            if hasattr(self.catalog_id, 'to_alipay_dict'):
                params['catalog_id'] = self.catalog_id.to_alipay_dict()
            else:
                params['catalog_id'] = self.catalog_id
        if self.catalog_name:
            if hasattr(self.catalog_name, 'to_alipay_dict'):
                params['catalog_name'] = self.catalog_name.to_alipay_dict()
            else:
                params['catalog_name'] = self.catalog_name
        if self.sepc_code:
            if hasattr(self.sepc_code, 'to_alipay_dict'):
                params['sepc_code'] = self.sepc_code.to_alipay_dict()
            else:
                params['sepc_code'] = self.sepc_code
        if self.service_code:
            if hasattr(self.service_code, 'to_alipay_dict'):
                params['service_code'] = self.service_code.to_alipay_dict()
            else:
                params['service_code'] = self.service_code
        if self.service_logo:
            if hasattr(self.service_logo, 'to_alipay_dict'):
                params['service_logo'] = self.service_logo.to_alipay_dict()
            else:
                params['service_logo'] = self.service_logo
        if self.service_name:
            if hasattr(self.service_name, 'to_alipay_dict'):
                params['service_name'] = self.service_name.to_alipay_dict()
            else:
                params['service_name'] = self.service_name
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = BoxExclusiveServiceOpenApiInfos()
        if 'appid' in d:
            o.appid = d['appid']
        if 'catalog_id' in d:
            o.catalog_id = d['catalog_id']
        if 'catalog_name' in d:
            o.catalog_name = d['catalog_name']
        if 'sepc_code' in d:
            o.sepc_code = d['sepc_code']
        if 'service_code' in d:
            o.service_code = d['service_code']
        if 'service_logo' in d:
            o.service_logo = d['service_logo']
        if 'service_name' in d:
            o.service_name = d['service_name']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayEbppIndustryOrderCreateModel(object):

    def __init__(self):
        self._ability_code = None
        self._bill_date = None
        self._bill_key = None
        self._biz_amount = None
        self._biz_inst_short_name = None
        self._biz_type = None
        self._city_code = None
        self._extend_field = None
        self._fine_amount = None
        self._identity_no = None
        self._mobile = None
        self._out_order_no = None
        self._owner_name = None
        self._province_code = None
        self._sub_biz_type = None

    @property
    def ability_code(self):
        return self._ability_code

    @ability_code.setter
    def ability_code(self, value):
        self._ability_code = value
    @property
    def bill_date(self):
        return self._bill_date

    @bill_date.setter
    def bill_date(self, value):
        self._bill_date = value
    @property
    def bill_key(self):
        return self._bill_key

    @bill_key.setter
    def bill_key(self, value):
        self._bill_key = value
    @property
    def biz_amount(self):
        return self._biz_amount

    @biz_amount.setter
    def biz_amount(self, value):
        self._biz_amount = value
    @property
    def biz_inst_short_name(self):
        return self._biz_inst_short_name

    @biz_inst_short_name.setter
    def biz_inst_short_name(self, value):
        self._biz_inst_short_name = value
    @property
    def biz_type(self):
        return self._biz_type

    @biz_type.setter
    def biz_type(self, value):
        self._biz_type = value
    @property
    def city_code(self):
        return self._city_code

    @city_code.setter
    def city_code(self, value):
        self._city_code = value
    @property
    def extend_field(self):
        return self._extend_field

    @extend_field.setter
    def extend_field(self, value):
        self._extend_field = value
    @property
    def fine_amount(self):
        return self._fine_amount

    @fine_amount.setter
    def fine_amount(self, value):
        self._fine_amount = value
    @property
    def identity_no(self):
        return self._identity_no

    @identity_no.setter
    def identity_no(self, value):
        self._identity_no = value
    @property
    def mobile(self):
        return self._mobile

    @mobile.setter
    def mobile(self, value):
        self._mobile = value
    @property
    def out_order_no(self):
        return self._out_order_no

    @out_order_no.setter
    def out_order_no(self, value):
        self._out_order_no = value
    @property
    def owner_name(self):
        return self._owner_name

    @owner_name.setter
    def owner_name(self, value):
        self._owner_name = value
    @property
    def province_code(self):
        return self._province_code

    @province_code.setter
    def province_code(self, value):
        self._province_code = value
    @property
    def sub_biz_type(self):
        return self._sub_biz_type

    @sub_biz_type.setter
    def sub_biz_type(self, value):
        self._sub_biz_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.ability_code:
            if hasattr(self.ability_code, 'to_alipay_dict'):
                params['ability_code'] = self.ability_code.to_alipay_dict()
            else:
                params['ability_code'] = self.ability_code
        if self.bill_date:
            if hasattr(self.bill_date, 'to_alipay_dict'):
                params['bill_date'] = self.bill_date.to_alipay_dict()
            else:
                params['bill_date'] = self.bill_date
        if self.bill_key:
            if hasattr(self.bill_key, 'to_alipay_dict'):
                params['bill_key'] = self.bill_key.to_alipay_dict()
            else:
                params['bill_key'] = self.bill_key
        if self.biz_amount:
            if hasattr(self.biz_amount, 'to_alipay_dict'):
                params['biz_amount'] = self.biz_amount.to_alipay_dict()
            else:
                params['biz_amount'] = self.biz_amount
        if self.biz_inst_short_name:
            if hasattr(self.biz_inst_short_name, 'to_alipay_dict'):
                params['biz_inst_short_name'] = self.biz_inst_short_name.to_alipay_dict()
            else:
                params['biz_inst_short_name'] = self.biz_inst_short_name
        if self.biz_type:
            if hasattr(self.biz_type, 'to_alipay_dict'):
                params['biz_type'] = self.biz_type.to_alipay_dict()
            else:
                params['biz_type'] = self.biz_type
        if self.city_code:
            if hasattr(self.city_code, 'to_alipay_dict'):
                params['city_code'] = self.city_code.to_alipay_dict()
            else:
                params['city_code'] = self.city_code
        if self.extend_field:
            if hasattr(self.extend_field, 'to_alipay_dict'):
                params['extend_field'] = self.extend_field.to_alipay_dict()
            else:
                params['extend_field'] = self.extend_field
        if self.fine_amount:
            if hasattr(self.fine_amount, 'to_alipay_dict'):
                params['fine_amount'] = self.fine_amount.to_alipay_dict()
            else:
                params['fine_amount'] = self.fine_amount
        if self.identity_no:
            if hasattr(self.identity_no, 'to_alipay_dict'):
                params['identity_no'] = self.identity_no.to_alipay_dict()
            else:
                params['identity_no'] = self.identity_no
        if self.mobile:
            if hasattr(self.mobile, 'to_alipay_dict'):
                params['mobile'] = self.mobile.to_alipay_dict()
            else:
                params['mobile'] = self.mobile
        if self.out_order_no:
            if hasattr(self.out_order_no, 'to_alipay_dict'):
                params['out_order_no'] = self.out_order_no.to_alipay_dict()
            else:
                params['out_order_no'] = self.out_order_no
        if self.owner_name:
            if hasattr(self.owner_name, 'to_alipay_dict'):
                params['owner_name'] = self.owner_name.to_alipay_dict()
            else:
                params['owner_name'] = self.owner_name
        if self.province_code:
            if hasattr(self.province_code, 'to_alipay_dict'):
                params['province_code'] = self.province_code.to_alipay_dict()
            else:
                params['province_code'] = self.province_code
        if self.sub_biz_type:
            if hasattr(self.sub_biz_type, 'to_alipay_dict'):
                params['sub_biz_type'] = self.sub_biz_type.to_alipay_dict()
            else:
                params['sub_biz_type'] = self.sub_biz_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEbppIndustryOrderCreateModel()
        if 'ability_code' in d:
            o.ability_code = d['ability_code']
        if 'bill_date' in d:
            o.bill_date = d['bill_date']
        if 'bill_key' in d:
            o.bill_key = d['bill_key']
        if 'biz_amount' in d:
            o.biz_amount = d['biz_amount']
        if 'biz_inst_short_name' in d:
            o.biz_inst_short_name = d['biz_inst_short_name']
        if 'biz_type' in d:
            o.biz_type = d['biz_type']
        if 'city_code' in d:
            o.city_code = d['city_code']
        if 'extend_field' in d:
            o.extend_field = d['extend_field']
        if 'fine_amount' in d:
            o.fine_amount = d['fine_amount']
        if 'identity_no' in d:
            o.identity_no = d['identity_no']
        if 'mobile' in d:
            o.mobile = d['mobile']
        if 'out_order_no' in d:
            o.out_order_no = d['out_order_no']
        if 'owner_name' in d:
            o.owner_name = d['owner_name']
        if 'province_code' in d:
            o.province_code = d['province_code']
        if 'sub_biz_type' in d:
            o.sub_biz_type = d['sub_biz_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.PlantPlace import PlantPlace
from alipay.aop.api.domain.UserCert import UserCert


class AlipaySocialForestCertificateQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipaySocialForestCertificateQueryResponse, self).__init__()
        self._cert_count_by_tree = None
        self._forest_user = None
        self._plant_place_info = None
        self._total_carbon_amount = None
        self._total_carbon_count = None
        self._total_cert_count = None
        self._user_certs = None

    @property
    def cert_count_by_tree(self):
        return self._cert_count_by_tree

    @cert_count_by_tree.setter
    def cert_count_by_tree(self, value):
        self._cert_count_by_tree = value
    @property
    def forest_user(self):
        return self._forest_user

    @forest_user.setter
    def forest_user(self, value):
        self._forest_user = value
    @property
    def plant_place_info(self):
        return self._plant_place_info

    @plant_place_info.setter
    def plant_place_info(self, value):
        if isinstance(value, PlantPlace):
            self._plant_place_info = value
        else:
            self._plant_place_info = PlantPlace.from_alipay_dict(value)
    @property
    def total_carbon_amount(self):
        return self._total_carbon_amount

    @total_carbon_amount.setter
    def total_carbon_amount(self, value):
        self._total_carbon_amount = value
    @property
    def total_carbon_count(self):
        return self._total_carbon_count

    @total_carbon_count.setter
    def total_carbon_count(self, value):
        self._total_carbon_count = value
    @property
    def total_cert_count(self):
        return self._total_cert_count

    @total_cert_count.setter
    def total_cert_count(self, value):
        self._total_cert_count = value
    @property
    def user_certs(self):
        return self._user_certs

    @user_certs.setter
    def user_certs(self, value):
        if isinstance(value, UserCert):
            self._user_certs = value
        else:
            self._user_certs = UserCert.from_alipay_dict(value)

    def parse_response_content(self, response_content):
        response = super(AlipaySocialForestCertificateQueryResponse, self).parse_response_content(response_content)
        if 'cert_count_by_tree' in response:
            self.cert_count_by_tree = response['cert_count_by_tree']
        if 'forest_user' in response:
            self.forest_user = response['forest_user']
        if 'plant_place_info' in response:
            self.plant_place_info = response['plant_place_info']
        if 'total_carbon_amount' in response:
            self.total_carbon_amount = response['total_carbon_amount']
        if 'total_carbon_count' in response:
            self.total_carbon_count = response['total_carbon_count']
        if 'total_cert_count' in response:
            self.total_cert_count = response['total_cert_count']
        if 'user_certs' in response:
            self.user_certs = response['user_certs']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class MybankFinanceAccountRysenterpriseQueryModel(object):

    def __init__(self):
        self._account_no = None
        self._ip_id = None
        self._ip_role_id = None
        self._out_channel_id = None
        self._out_channel_type = None
        self._scene_code = None
        self._tnt_inst_id = None

    @property
    def account_no(self):
        return self._account_no

    @account_no.setter
    def account_no(self, value):
        self._account_no = value
    @property
    def ip_id(self):
        return self._ip_id

    @ip_id.setter
    def ip_id(self, value):
        self._ip_id = value
    @property
    def ip_role_id(self):
        return self._ip_role_id

    @ip_role_id.setter
    def ip_role_id(self, value):
        self._ip_role_id = value
    @property
    def out_channel_id(self):
        return self._out_channel_id

    @out_channel_id.setter
    def out_channel_id(self, value):
        self._out_channel_id = value
    @property
    def out_channel_type(self):
        return self._out_channel_type

    @out_channel_type.setter
    def out_channel_type(self, value):
        self._out_channel_type = value
    @property
    def scene_code(self):
        return self._scene_code

    @scene_code.setter
    def scene_code(self, value):
        self._scene_code = value
    @property
    def tnt_inst_id(self):
        return self._tnt_inst_id

    @tnt_inst_id.setter
    def tnt_inst_id(self, value):
        self._tnt_inst_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.account_no:
            if hasattr(self.account_no, 'to_alipay_dict'):
                params['account_no'] = self.account_no.to_alipay_dict()
            else:
                params['account_no'] = self.account_no
        if self.ip_id:
            if hasattr(self.ip_id, 'to_alipay_dict'):
                params['ip_id'] = self.ip_id.to_alipay_dict()
            else:
                params['ip_id'] = self.ip_id
        if self.ip_role_id:
            if hasattr(self.ip_role_id, 'to_alipay_dict'):
                params['ip_role_id'] = self.ip_role_id.to_alipay_dict()
            else:
                params['ip_role_id'] = self.ip_role_id
        if self.out_channel_id:
            if hasattr(self.out_channel_id, 'to_alipay_dict'):
                params['out_channel_id'] = self.out_channel_id.to_alipay_dict()
            else:
                params['out_channel_id'] = self.out_channel_id
        if self.out_channel_type:
            if hasattr(self.out_channel_type, 'to_alipay_dict'):
                params['out_channel_type'] = self.out_channel_type.to_alipay_dict()
            else:
                params['out_channel_type'] = self.out_channel_type
        if self.scene_code:
            if hasattr(self.scene_code, 'to_alipay_dict'):
                params['scene_code'] = self.scene_code.to_alipay_dict()
            else:
                params['scene_code'] = self.scene_code
        if self.tnt_inst_id:
            if hasattr(self.tnt_inst_id, 'to_alipay_dict'):
                params['tnt_inst_id'] = self.tnt_inst_id.to_alipay_dict()
            else:
                params['tnt_inst_id'] = self.tnt_inst_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MybankFinanceAccountRysenterpriseQueryModel()
        if 'account_no' in d:
            o.account_no = d['account_no']
        if 'ip_id' in d:
            o.ip_id = d['ip_id']
        if 'ip_role_id' in d:
            o.ip_role_id = d['ip_role_id']
        if 'out_channel_id' in d:
            o.out_channel_id = d['out_channel_id']
        if 'out_channel_type' in d:
            o.out_channel_type = d['out_channel_type']
        if 'scene_code' in d:
            o.scene_code = d['scene_code']
        if 'tnt_inst_id' in d:
            o.tnt_inst_id = d['tnt_inst_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayIserviceCcmSwLibraryDeleteModel(object):

    def __init__(self):
        self._ccs_instance_id = None
        self._id = None

    @property
    def ccs_instance_id(self):
        return self._ccs_instance_id

    @ccs_instance_id.setter
    def ccs_instance_id(self, value):
        self._ccs_instance_id = value
    @property
    def id(self):
        return self._id

    @id.setter
    def id(self, value):
        self._id = value


    def to_alipay_dict(self):
        params = dict()
        if self.ccs_instance_id:
            if hasattr(self.ccs_instance_id, 'to_alipay_dict'):
                params['ccs_instance_id'] = self.ccs_instance_id.to_alipay_dict()
            else:
                params['ccs_instance_id'] = self.ccs_instance_id
        if self.id:
            if hasattr(self.id, 'to_alipay_dict'):
                params['id'] = self.id.to_alipay_dict()
            else:
                params['id'] = self.id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayIserviceCcmSwLibraryDeleteModel()
        if 'ccs_instance_id' in d:
            o.ccs_instance_id = d['ccs_instance_id']
        if 'id' in d:
            o.id = d['id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.TicketTransInfo import TicketTransInfo


class KoubeiTradeTicketTicketcodeQueryResponse(AlipayResponse):

    def __init__(self):
        super(KoubeiTradeTicketTicketcodeQueryResponse, self).__init__()
        self._available_quantity = None
        self._current_price = None
        self._effect_date = None
        self._expire_date = None
        self._item_alias = None
        self._item_id = None
        self._item_name = None
        self._order_no = None
        self._original_price = None
        self._ticket_code = None
        self._ticket_status = None
        self._ticket_status_desc = None
        self._ticket_trans_info_list = None
        self._time_cards = None
        self._tm_item_id = None
        self._total_quantity = None
        self._voucher_id = None

    @property
    def available_quantity(self):
        return self._available_quantity

    @available_quantity.setter
    def available_quantity(self, value):
        self._available_quantity = value
    @property
    def current_price(self):
        return self._current_price

    @current_price.setter
    def current_price(self, value):
        self._current_price = value
    @property
    def effect_date(self):
        return self._effect_date

    @effect_date.setter
    def effect_date(self, value):
        self._effect_date = value
    @property
    def expire_date(self):
        return self._expire_date

    @expire_date.setter
    def expire_date(self, value):
        self._expire_date = value
    @property
    def item_alias(self):
        return self._item_alias

    @item_alias.setter
    def item_alias(self, value):
        self._item_alias = value
    @property
    def item_id(self):
        return self._item_id

    @item_id.setter
    def item_id(self, value):
        self._item_id = value
    @property
    def item_name(self):
        return self._item_name

    @item_name.setter
    def item_name(self, value):
        self._item_name = value
    @property
    def order_no(self):
        return self._order_no

    @order_no.setter
    def order_no(self, value):
        self._order_no = value
    @property
    def original_price(self):
        return self._original_price

    @original_price.setter
    def original_price(self, value):
        self._original_price = value
    @property
    def ticket_code(self):
        return self._ticket_code

    @ticket_code.setter
    def ticket_code(self, value):
        self._ticket_code = value
    @property
    def ticket_status(self):
        return self._ticket_status

    @ticket_status.setter
    def ticket_status(self, value):
        self._ticket_status = value
    @property
    def ticket_status_desc(self):
        return self._ticket_status_desc

    @ticket_status_desc.setter
    def ticket_status_desc(self, value):
        self._ticket_status_desc = value
    @property
    def ticket_trans_info_list(self):
        return self._ticket_trans_info_list

    @ticket_trans_info_list.setter
    def ticket_trans_info_list(self, value):
        if isinstance(value, list):
            self._ticket_trans_info_list = list()
            for i in value:
                if isinstance(i, TicketTransInfo):
                    self._ticket_trans_info_list.append(i)
                else:
                    self._ticket_trans_info_list.append(TicketTransInfo.from_alipay_dict(i))
    @property
    def time_cards(self):
        return self._time_cards

    @time_cards.setter
    def time_cards(self, value):
        self._time_cards = value
    @property
    def tm_item_id(self):
        return self._tm_item_id

    @tm_item_id.setter
    def tm_item_id(self, value):
        self._tm_item_id = value
    @property
    def total_quantity(self):
        return self._total_quantity

    @total_quantity.setter
    def total_quantity(self, value):
        self._total_quantity = value
    @property
    def voucher_id(self):
        return self._voucher_id

    @voucher_id.setter
    def voucher_id(self, value):
        self._voucher_id = value

    def parse_response_content(self, response_content):
        response = super(KoubeiTradeTicketTicketcodeQueryResponse, self).parse_response_content(response_content)
        if 'available_quantity' in response:
            self.available_quantity = response['available_quantity']
        if 'current_price' in response:
            self.current_price = response['current_price']
        if 'effect_date' in response:
            self.effect_date = response['effect_date']
        if 'expire_date' in response:
            self.expire_date = response['expire_date']
        if 'item_alias' in response:
            self.item_alias = response['item_alias']
        if 'item_id' in response:
            self.item_id = response['item_id']
        if 'item_name' in response:
            self.item_name = response['item_name']
        if 'order_no' in response:
            self.order_no = response['order_no']
        if 'original_price' in response:
            self.original_price = response['original_price']
        if 'ticket_code' in response:
            self.ticket_code = response['ticket_code']
        if 'ticket_status' in response:
            self.ticket_status = response['ticket_status']
        if 'ticket_status_desc' in response:
            self.ticket_status_desc = response['ticket_status_desc']
        if 'ticket_trans_info_list' in response:
            self.ticket_trans_info_list = response['ticket_trans_info_list']
        if 'time_cards' in response:
            self.time_cards = response['time_cards']
        if 'tm_item_id' in response:
            self.tm_item_id = response['tm_item_id']
        if 'total_quantity' in response:
            self.total_quantity = response['total_quantity']
        if 'voucher_id' in response:
            self.voucher_id = response['voucher_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class PromoContentApiSchemaVO(object):

    def __init__(self):
        self._demo_pic = None
        self._schema_id = None
        self._schema_xml = None

    @property
    def demo_pic(self):
        return self._demo_pic

    @demo_pic.setter
    def demo_pic(self, value):
        self._demo_pic = value
    @property
    def schema_id(self):
        return self._schema_id

    @schema_id.setter
    def schema_id(self, value):
        self._schema_id = value
    @property
    def schema_xml(self):
        return self._schema_xml

    @schema_xml.setter
    def schema_xml(self, value):
        self._schema_xml = value


    def to_alipay_dict(self):
        params = dict()
        if self.demo_pic:
            if hasattr(self.demo_pic, 'to_alipay_dict'):
                params['demo_pic'] = self.demo_pic.to_alipay_dict()
            else:
                params['demo_pic'] = self.demo_pic
        if self.schema_id:
            if hasattr(self.schema_id, 'to_alipay_dict'):
                params['schema_id'] = self.schema_id.to_alipay_dict()
            else:
                params['schema_id'] = self.schema_id
        if self.schema_xml:
            if hasattr(self.schema_xml, 'to_alipay_dict'):
                params['schema_xml'] = self.schema_xml.to_alipay_dict()
            else:
                params['schema_xml'] = self.schema_xml
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = PromoContentApiSchemaVO()
        if 'demo_pic' in d:
            o.demo_pic = d['demo_pic']
        if 'schema_id' in d:
            o.schema_id = d['schema_id']
        if 'schema_xml' in d:
            o.schema_xml = d['schema_xml']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayMarketingCampaignRuleCrowdCreateResponse(AlipayResponse):

    def __init__(self):
        super(AlipayMarketingCampaignRuleCrowdCreateResponse, self).__init__()
        self._ruleid = None

    @property
    def ruleid(self):
        return self._ruleid

    @ruleid.setter
    def ruleid(self, value):
        self._ruleid = value

    def parse_response_content(self, response_content):
        response = super(AlipayMarketingCampaignRuleCrowdCreateResponse, self).parse_response_content(response_content)
        if 'ruleid' in response:
            self.ruleid = response['ruleid']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class KoubeiCateringDishCommruleQueryModel(object):

    def __init__(self):
        self._biz_id = None
        self._comm_group_id = None
        self._group_detail_id = None
        self._page_no = None
        self._page_size = None
        self._rule_id = None
        self._rule_type = None

    @property
    def biz_id(self):
        return self._biz_id

    @biz_id.setter
    def biz_id(self, value):
        self._biz_id = value
    @property
    def comm_group_id(self):
        return self._comm_group_id

    @comm_group_id.setter
    def comm_group_id(self, value):
        self._comm_group_id = value
    @property
    def group_detail_id(self):
        return self._group_detail_id

    @group_detail_id.setter
    def group_detail_id(self, value):
        self._group_detail_id = value
    @property
    def page_no(self):
        return self._page_no

    @page_no.setter
    def page_no(self, value):
        self._page_no = value
    @property
    def page_size(self):
        return self._page_size

    @page_size.setter
    def page_size(self, value):
        self._page_size = value
    @property
    def rule_id(self):
        return self._rule_id

    @rule_id.setter
    def rule_id(self, value):
        self._rule_id = value
    @property
    def rule_type(self):
        return self._rule_type

    @rule_type.setter
    def rule_type(self, value):
        self._rule_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_id:
            if hasattr(self.biz_id, 'to_alipay_dict'):
                params['biz_id'] = self.biz_id.to_alipay_dict()
            else:
                params['biz_id'] = self.biz_id
        if self.comm_group_id:
            if hasattr(self.comm_group_id, 'to_alipay_dict'):
                params['comm_group_id'] = self.comm_group_id.to_alipay_dict()
            else:
                params['comm_group_id'] = self.comm_group_id
        if self.group_detail_id:
            if hasattr(self.group_detail_id, 'to_alipay_dict'):
                params['group_detail_id'] = self.group_detail_id.to_alipay_dict()
            else:
                params['group_detail_id'] = self.group_detail_id
        if self.page_no:
            if hasattr(self.page_no, 'to_alipay_dict'):
                params['page_no'] = self.page_no.to_alipay_dict()
            else:
                params['page_no'] = self.page_no
        if self.page_size:
            if hasattr(self.page_size, 'to_alipay_dict'):
                params['page_size'] = self.page_size.to_alipay_dict()
            else:
                params['page_size'] = self.page_size
        if self.rule_id:
            if hasattr(self.rule_id, 'to_alipay_dict'):
                params['rule_id'] = self.rule_id.to_alipay_dict()
            else:
                params['rule_id'] = self.rule_id
        if self.rule_type:
            if hasattr(self.rule_type, 'to_alipay_dict'):
                params['rule_type'] = self.rule_type.to_alipay_dict()
            else:
                params['rule_type'] = self.rule_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiCateringDishCommruleQueryModel()
        if 'biz_id' in d:
            o.biz_id = d['biz_id']
        if 'comm_group_id' in d:
            o.comm_group_id = d['comm_group_id']
        if 'group_detail_id' in d:
            o.group_detail_id = d['group_detail_id']
        if 'page_no' in d:
            o.page_no = d['page_no']
        if 'page_size' in d:
            o.page_size = d['page_size']
        if 'rule_id' in d:
            o.rule_id = d['rule_id']
        if 'rule_type' in d:
            o.rule_type = d['rule_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class MerchantIndirectSmidVerifyResultRecord(object):

    def __init__(self):
        self._org_id = None
        self._smid = None
        self._source_id = None
        self._verifiy_failed_msg = None
        self._verifiy_result = None

    @property
    def org_id(self):
        return self._org_id

    @org_id.setter
    def org_id(self, value):
        self._org_id = value
    @property
    def smid(self):
        return self._smid

    @smid.setter
    def smid(self, value):
        self._smid = value
    @property
    def source_id(self):
        return self._source_id

    @source_id.setter
    def source_id(self, value):
        self._source_id = value
    @property
    def verifiy_failed_msg(self):
        return self._verifiy_failed_msg

    @verifiy_failed_msg.setter
    def verifiy_failed_msg(self, value):
        self._verifiy_failed_msg = value
    @property
    def verifiy_result(self):
        return self._verifiy_result

    @verifiy_result.setter
    def verifiy_result(self, value):
        self._verifiy_result = value


    def to_alipay_dict(self):
        params = dict()
        if self.org_id:
            if hasattr(self.org_id, 'to_alipay_dict'):
                params['org_id'] = self.org_id.to_alipay_dict()
            else:
                params['org_id'] = self.org_id
        if self.smid:
            if hasattr(self.smid, 'to_alipay_dict'):
                params['smid'] = self.smid.to_alipay_dict()
            else:
                params['smid'] = self.smid
        if self.source_id:
            if hasattr(self.source_id, 'to_alipay_dict'):
                params['source_id'] = self.source_id.to_alipay_dict()
            else:
                params['source_id'] = self.source_id
        if self.verifiy_failed_msg:
            if hasattr(self.verifiy_failed_msg, 'to_alipay_dict'):
                params['verifiy_failed_msg'] = self.verifiy_failed_msg.to_alipay_dict()
            else:
                params['verifiy_failed_msg'] = self.verifiy_failed_msg
        if self.verifiy_result:
            if hasattr(self.verifiy_result, 'to_alipay_dict'):
                params['verifiy_result'] = self.verifiy_result.to_alipay_dict()
            else:
                params['verifiy_result'] = self.verifiy_result
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MerchantIndirectSmidVerifyResultRecord()
        if 'org_id' in d:
            o.org_id = d['org_id']
        if 'smid' in d:
            o.smid = d['smid']
        if 'source_id' in d:
            o.source_id = d['source_id']
        if 'verifiy_failed_msg' in d:
            o.verifiy_failed_msg = d['verifiy_failed_msg']
        if 'verifiy_result' in d:
            o.verifiy_result = d['verifiy_result']
        return o


